@@ -5,17 +5,17 @@
 # This script automates creating universal binaries of LyX on Mac.
 # Author: Bennett Helm (and extended by Konrad Hofbauer)
 # latest changes by Stephan Witt
-# Last modified: January 2013
+# Last modified: July 2014
 
-Qt4API=${Qt4API:-"-cocoa"}
-Qt4Version=${Qt4Version:-"4.6.3"}
-Qt4SourceVersion="qt-everywhere-opensource-src-${Qt4Version}"
-Qt4BuildSubDir="qt-${Qt4Version}-build${Qt4API}"
-Qt4ConfigureOptions=${Qt4ConfigureOptions:-"-release"}
+QtAPI=${QtAPI:-"-cocoa"}
+QtVersion=${QtVersion:-"4.6.3"}
+QtSourceVersion="qt-everywhere-opensource-src-${QtVersion}"
+QtBuildSubDir="qt-${QtVersion}-build${QtAPI}"
+QtConfigureOptions=${QtConfigureOptions:-"-release"}
 
-GettextVersion=${GettextVersion:-"0.18.2"}
-GettextSource="gettext-${GettextVersion}"
-GettextLibrary="libintl.8.dylib"
+LibMagicVersion=${LibMagicVersion:-"5.19"}
+LibMagicSource="file-${LibMagicVersion}"
+LibMagicLibrary="libmagic.1.dylib"
 
 ASpellVersion=${ASpellVersion:-"0.60.6.1"}
 ASpellSource="aspell-${ASpellVersion}"
@@ -29,53 +29,81 @@ unset DYLD_LIBRARY_PATH LD_LIBRARY_PATH
 
 # Prerequisite:
 # * a decent checkout of LyX sources (probably you have it already)
-# * Qt4 - build with shared or static libraries for the used platforms (default: i386 and ppc)
-#    or - an unpacked source tree of Qt4 in $QT4SOURCEDIR or in the sibling directory (variable Qt4SourceVersion)
+# * Qt - build with shared or static libraries for the used platforms (default: i386 and ppc)
+#   or - an unpacked source tree of Qt in $QTSOURCEDIR or in the sibling directory (variable QtSourceVersion)
 # * for aspell support:
 #   the aspell sources placed in a sibling directory (variable ASpellSource)
 # * for hunspell support:
 #   the hunspell sources placed in a sibling directory (variable HunSpellSource)
-# * for dictionary deployment (per default thesauri only):
+# * for dictionary deployment (only hunspell dicts and mythes thesauri are deployed per default):
 #   - aspell:   the dictionary files of macports (in /opt/local/share/aspell and /opt/local/lib/aspell-0.60)
 #   - hunspell: the dictionary files in the sibling directory dictionaries/dicts
 #   - mythes:   the data and idx files in the sibling directory dictionaries/thes
+# * for magic file type detection support:
+#   the libmagic sources placed in a sibling directory (variable LibMagicSource)
 
 LyXConfigureOptions="--enable-warnings --enable-optimization=-Os --with-x=no"
 LyXConfigureOptions="${LyXConfigureOptions} --disable-stdlib-debug"
 AspellConfigureOptions="--enable-warnings --enable-optimization=-O0 --enable-debug --disable-nls --enable-compile-in-filters --disable-pspell-compatibility"
 HunspellConfigureOptions="--with-warnings --disable-nls --disable-static"
-Qt4ConfigureOptions="${QtConfigureOptions} -opensource -silent -shared -fast -no-exceptions"
-Qt4ConfigureOptions="${Qt4ConfigureOptions} -no-webkit -no-qt3support -no-javascript-jit -no-dbus"
-Qt4ConfigureOptions="${Qt4ConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
-Qt4DmgSuffix=qt4${Qt4API}.dmg
 
+QtMajorVersion=qt4
+QtConfigureOptions="${QtConfigureOptions} -opensource -silent -shared -confirm-license"
 # stupid special case...
-case "${Qt4Version}:${Qt4API}" in
+case "${QtVersion}:${QtAPI}" in
 4.6*:-carbon)
+	QtConfigureOptions="${QtConfigureOptions} -fast -no-exceptions"
+	QtConfigureOptions="${QtConfigureOptions} -no-webkit -no-qt3support -no-javascript-jit -no-dbus"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
+	for arch in ${ARCH_LIST} ; do
+		QTARCHS="${QTARCHS} -arch ${arch}"
+	done
 	;;
 5.0*)
-	Qt4ConfigureOptions="${QtConfigureOptions} -opensource -silent -shared -fast -no-strip"
-	Qt4ConfigureOptions="${Qt4ConfigureOptions} -no-javascript-jit -no-pkg-config"
-	Qt4ConfigureOptions="${Qt4ConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
-	Qt4DmgSuffix=qt5${Qt4API}.dmg
+	QtConfigureOptions="${QtConfigureOptions} -fast -no-strip"
+	QtConfigureOptions="${QtConfigureOptions} -no-javascript-jit -no-pkg-config"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
+	QtMajorVersion=qt5
+	;;
+5.6*)
+	QtConfigureOptions="${QtConfigureOptions} -no-strip"
+	QtConfigureOptions="${QtConfigureOptions} -no-kms -no-pkg-config"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake tools"
+	QtConfigureOptions="${QtConfigureOptions} -skip qtconnectivity -skip qtscript"
+	QtConfigureOptions="${QtConfigureOptions} -skip qtquickcontrols"
+	QtConfigureOptions="${QtConfigureOptions} -skip qttools"
+	QtConfigureOptions="${QtConfigureOptions} -skip qtdeclarative"
+	QtMajorVersion=qt5
 	;;
 5.*)
-	Qt4DmgSuffix=qt5${Qt4API}.dmg
+	QtConfigureOptions="${QtConfigureOptions} -no-strip"
+	QtConfigureOptions="${QtConfigureOptions} -no-kms -no-pkg-config"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake tools"
+	QtConfigureOptions="${QtConfigureOptions} -skip qtquick1 -skip qtwebkit -skip qtconnectivity -skip qtscript"
+	QtConfigureOptions="${QtConfigureOptions} -skip qtquickcontrols"
+#	QtConfigureOptions="${QtConfigureOptions} -skip qtdeclarative"
+	QtMajorVersion=qt5
 	;;
 *)
-	Qt4ConfigureOptions="${Qt4ConfigureOptions} ${Qt4API}"
+	QtConfigureOptions="${QtConfigureOptions} -fast -no-exceptions"
+	QtConfigureOptions="${QtConfigureOptions} -no-webkit -no-qt3support -no-javascript-jit -no-dbus"
+	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake demos -nomake docs -nomake tools"
+	QtConfigureOptions="${QtConfigureOptions} ${QtAPI}"
+	for arch in ${ARCH_LIST} ; do
+		QTARCHS="${QTARCHS} -arch ${arch}"
+	done
 	;;
 esac
 
 aspell_dictionaries="no"
 hunspell_dictionaries="yes"
 
-gettext_deployment="no"
+libmagic_deployment="yes"
 aspell_deployment="yes"
 hunspell_deployment="yes"
 thesaurus_deployment="yes"
 
-qt4_deployment="yes"
+qt_deployment="yes"
 
 # auto detect Xcode location
 DEVELOPER_SDKS=$(dirname $(xcrun --show-sdk-path))
@@ -116,22 +144,28 @@ usage() {
 	echo
 	echo Optional arguments:
 	echo " --aspell-deployment=yes|no ." default yes
-	echo " --with-qt4-frameworks=yes|no" default no
-	echo " --qt4-deployment=yes|no ...." default yes
+	echo " --with-qt-frameworks=yes|no." default no
+	echo " --qt-deployment=yes|no ....." default yes
 	echo " --with-macosx-target=TARGET " default 10.4 "(Tiger)"
 	echo " --with-sdkroot=SDKROOT ....." default 10.5 "(Leopard)"
 	echo " --with-arch=ARCH ..........." default ppc,i386
 	echo " --with-build-path=PATH ....." default \${lyx-src-dir}/../lyx-build
 	echo " --with-dmg-location=PATH ..." default \${build-path}
+	echo " --with-binary-strip=yes ...." default no
 	echo
 	echo "All other arguments with -- are passed to configure"
 	echo "including the defaults: ${LyXConfigureOptions}"
-	if [ -x "${LyxSourceDir}/configure" ]; then
-		echo
-		echo "*" Configure options of LyX
-		echo
-		"${LyxSourceDir}/configure" --help
-	fi
+	case "${1}" in
+	--help=short)
+		;;
+	*)
+		if [ -x "${LyxSourceDir}/configure" ]; then
+			echo
+			echo "*" Configure options of LyX
+			echo
+			"${LyxSourceDir}/configure" --help
+		fi
+	esac
 	exit 0
 }
 
@@ -143,15 +177,15 @@ fi
 
 while [ $# -gt 0 ]; do
 	case "${1}" in
-	--with-qt4-frameworks=*)
-		configure_qt4_frameworks=$(echo ${1}|cut -d= -f2)
-		if [ "$configure_qt4_frameworks" = "yes" ]; then
+	--with-qt-frameworks=*)
+		configure_qt_frameworks=$(echo ${1}|cut -d= -f2)
+		if [ "$configure_qt_frameworks" = "yes" ]; then
 			unset QTDIR
-			qt4_deployment="no"
+			qt_deployment="no"
 		fi
 		shift
 		;;
-	--with-qt4-dir=*)
+	--with-qt-dir=*)
 		QTDIR=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
@@ -178,8 +212,8 @@ while [ $# -gt 0 ]; do
 		esac
 		shift
 		;;
-	--gettext-deployment=*)
-		gettext_deployment=$(echo ${1}|cut -d= -f2)
+	--libmagic-deployment=*)
+		libmagic_deployment=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
 	--aspell-deployment=*)
@@ -196,8 +230,8 @@ while [ $# -gt 0 ]; do
 		thesaurus_deployment=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
-	--qt4-deployment=*)
-		qt4_deployment=$(echo ${1}|cut -d= -f2)
+	--qt-deployment=*)
+		qt_deployment=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
 	--with-arch=*)
@@ -209,6 +243,10 @@ while [ $# -gt 0 ]; do
 		DMGLocation=$(echo ${1}|cut -d= -f2)
 		shift
 		;;
+	--with-binary-strip=yes)
+		strip="-strip"
+		shift
+		;;
 	--with-build-path=*)
 		LyxBuildDir=$(echo ${1}|cut -d= -f2)
 		shift
@@ -218,7 +256,7 @@ while [ $# -gt 0 ]; do
 		shift
 		;;
 	--help|--help=*)
-		usage
+		usage "${1}"
 		;;
 	--without-aspell)
 		LyXConfigureOptions="${LyXConfigureOptions} ${1}"
@@ -230,6 +268,10 @@ while [ $# -gt 0 ]; do
 		hunspell_deployment="no"
 		shift
 		;;
+	--only-qt*=*)
+		QtOnlyPackage=$(echo ${1}|cut -d= -f2)
+		shift
+		;;
 	--only-package=*)
 		LyxOnlyPackage=$(echo ${1}|cut -d= -f2)
 		shift
@@ -244,13 +286,12 @@ while [ $# -gt 0 ]; do
 	esac
 done
 
-if [ "${configure_qt4_frameworks}" != "yes" ]; then
+if [ "${configure_qt_frameworks}" != "yes" ]; then
 	QtInstallDir=${QTDIR:-"/opt/qt4"}
 fi
 
 ARCH_LIST=${ARCH_LIST:-"ppc i386"}
 
-strip="-strip"
 aspellstrip=
 
 LyxBuildDir=${LyxBuildDir:-$(dirname "${LyxSourceDir}")/lyx-build}
@@ -258,10 +299,10 @@ DMGLocation=${DMGLocation:-"${LyxBuildDir}"}
 
 LyXUtilitiesDir=${LyXUtilitiesDir:-"${LyxBuildDir}"/utilities}
 
-GettextSourceDir=${GETTEXTDIR:-$(dirname "${LyxSourceDir}")/${GettextSource}}
-GettextBuildDir="${LyxBuildDir}"/"${GettextSource}"
-GettextInstallDir=${GettextInstallDir:-"${LyXUtilitiesDir}"}
-GettextInstallHdr="${GettextInstallDir}/include/libintl.h"
+LibMagicSourceDir=${LIBMAGICDIR:-$(dirname "${LyxSourceDir}")/${LibMagicSource}}
+LibMagicBuildDir="${LyxBuildDir}"/"${LibMagicSource}"
+LibMagicInstallDir=${LibMagicInstallDir:-"${LyXUtilitiesDir}"}
+LibMagicInstallHdr="${LibMagicInstallDir}/include/magic.h"
 
 ASpellSourceDir=${ASPELLDIR:-$(dirname "${LyxSourceDir}")/${ASpellSource}}
 ASpellBuildDir="${ASpellSourceDir}"
@@ -273,8 +314,8 @@ HunSpellBuildDir="${HunSpellSourceDir}"
 HunSpellInstallDir=${HunSpellInstallDir:-"${LyXUtilitiesDir}"}
 HunSpellInstallHdr="${HunSpellInstallDir}/include/hunspell/hunspell.h"
 
-Qt4SourceDir=${QT4SOURCEDIR:-$(dirname "${LyxSourceDir}")/${Qt4SourceVersion}}
-Qt4BuildDir=${Qt4BuildDir:-"${LyxBuildDir}"/${Qt4BuildSubDir:-"qt4-build"}}
+QtSourceDir=${QTSOURCEDIR:-$(dirname "${LyxSourceDir}")/${QtSourceVersion}}
+QtBuildDir=${QtBuildDir:-"${LyxBuildDir}"/${QtBuildSubDir:-"qt-build"}}
 
 DictionarySourceDir=${DICTIONARYDIR:-$(dirname "${LyxSourceDir}")/dictionaries}
 DocumentationDir=$(dirname "${LyxSourceDir}")/Documents
@@ -284,6 +325,11 @@ if [ -z "${LyXVersion}" ]; then
 	LyXVersion=$(grep AC_INIT "${LyxSourceDir}"/configure.ac | cut -d, -f2 | tr -d " ()")
 fi
 LyXVersionSuffix=${LyXVersionSuffix:-$(echo "${LyXVersion}" | cut -d. -f1-2)}
+case "${LyXVersion}" in
+*dev*)
+	LyXGitCommitHash=$(cd "${LyxSourceDir}" ; git log -1 --pretty=format:%h)
+	;;
+esac
 
 LyxName="LyX"
 LyxBase="${LyxName}-${LyXVersion}"
@@ -299,22 +345,26 @@ LyxAppPrefix="${LyxAppDir}.app"
 # ---------------------------------
 
 # don't change order here...
-case "${Qt4Version}" in
+case "${QtVersion}" in
 5.0.*|5.1.*)
 	QtLibraries="QtSvg QtXml QtPrintSupport QtWidgets QtGui QtNetwork QtConcurrent QtCore"
 	QtFrameworkVersion="5"
 	;;
-5*)
+5.2.*|5.3.*|5.4.*)
 	QtLibraries="QtSvg QtXml QtPrintSupport QtMacExtras QtWidgets QtGui QtNetwork QtConcurrent QtCore"
 	QtFrameworkVersion="5"
 	;;
+5*)
+	QtLibraries="QtSvg QtXml QtPrintSupport QtDBus QtMacExtras QtWidgets QtGui QtNetwork QtConcurrent QtCore"
+	QtFrameworkVersion="5"
+	;;
 *)
 	QtLibraries="QtSvg QtXml QtGui QtNetwork QtCore"
 	QtFrameworkVersion="4"
 	;;
 esac
 
-DMGNAME="${LyxBase}"
+DMGNAME="${LyxBase}${LyXGitCommitHash:+-}${LyXGitCommitHash}"
 DMGSIZE="550m"
 
 # Check for existing SDKs
@@ -344,78 +394,78 @@ case $SDKs in
 esac
 MYCFLAGS="-mmacosx-version-min=${MACOSX_DEPLOYMENT_TARGET}"
 
-# pkg-config is not usable with this script
-export PKG_CONFIG=""
-
-# These variables define the identifiers of the
-# system (both Intel and PowerPC) to compile for.
-# (Note: darwin8 is 10.4; darwin9 is 10.5.)
-# Only change these if necessary
-
-HostSystem_i386="i686-apple-darwin8"
-HostSystem_ppc="powerpc-apple-darwin8"
-
-if [ "${configure_qt4_frameworks}" != "yes" -a -d "${Qt4SourceDir}" -a ! \( -d "${Qt4BuildDir}" -a -d "${QtInstallDir}" \) ]; then
-	echo Build Qt4 library ${Qt4SourceDir}
-	if [ "${QtInstallDir}" = "${Qt4BuildDir}" ]; then
+build_qt() {
+	echo Build Qt library ${QtSourceDir}
+	if [ "${QtInstallDir}" = "${QtBuildDir}" ]; then
 		echo Bad install directory for Qt.
-		echo Must be different from build directory "${Qt4BuildDir}".
+		echo Must be different from build directory "${QtBuildDir}".
 		exit 1
 	fi
 	(
-		mkdir -p "${Qt4BuildDir}" && cd "${Qt4BuildDir}"
-		for arch in ${ARCH_LIST} ; do
-			ARCHS="${ARCHS} -arch ${arch}"
-		done
+		mkdir -p "${QtBuildDir}" && cd "${QtBuildDir}"
 		echo configure options:
-		echo ${Qt4ConfigureOptions} ${ARCHS} -prefix "${QtInstallDir}"
-		echo yes | "${Qt4SourceDir}"/configure ${Qt4ConfigureOptions} ${ARCHS} -prefix "${QtInstallDir}"
-		make ${MAKEJOBS} && make install
+		echo ${QtConfigureOptions} ${QTARCHS} -prefix "${QtInstallDir}"
+		"${QtSourceDir}"/configure ${QtConfigureOptions} ${QTARCHS} -prefix "${QtInstallDir}"
+		make -j1 && make -j1 install
 	)
-	cd "${QtInstallDir}" && (
-		mkdir -p include
-		cd include
-		for libnm in ${QtLibraries} ; do
-			test -d ${libnm} -o -L ${libnm} || ln -s ../lib/${libnm}.framework/Headers ${libnm}
-		done
-	)
-fi
+	if [ -d "${QtInstallDir}" -a ! -f "${QtInstallDir}"/include/QtCore ]; then
+		cd "${QtInstallDir}" && (
+			mkdir -p include
+			cd include
+			for libnm in ${QtLibraries} ; do
+				test -d ${libnm} -o -L ${libnm} || \
+				( ln -s ../lib/${libnm}.framework/Headers ${libnm} && echo Link to framework ${libnm} )
+			done
+		)
+	fi
+}
 
-if [ -d "${GettextSourceDir}" -a ! -f "${GettextInstallHdr}" ]; then
-	# we have a private Gettext source tree at hand...
+case ${QtOnlyPackage:-"no"} in
+y*)
+	build_qt
+	exit 0
+	;;
+*)
+	if [ "${configure_qt_frameworks}" != "yes" -a -d "${QtSourceDir}" -a ! \( -d "${QtBuildDir}" -a -d "${QtInstallDir}" \) ]; then
+		build_qt
+	fi
+	;;
+esac
+
+if [ -d "${LibMagicSourceDir}" -a ! -f "${LibMagicInstallHdr}" ]; then
+	# we have a private libmagic (file(1)) source tree at hand...
 	# so let's build and install it
-	if [ -z "${GettextVersion}" ]; then
-		GettextVersion=$(grep AC_INIT "${GettextSourceDir}"/configure.ac | cut -d, -f2|tr -d " ()")
+	if [ -z "${LibMagicVersion}" ]; then
+		LibMagicVersion=$(grep AC_INIT "${LibMagicSourceDir}"/configure.ac | cut -d, -f2|tr -d " ()")
 	fi
 
-	GettextName="Gettext"
-	GettextBase="${GettextName}-${GettextVersion}"
+	LibMagicName="LibMagic"
+	LibMagicBase="${LibMagicName}-${LibMagicVersion}"
 
-	echo Build gettext library ${GettextBase}
+	echo Build libmagic library ${LibMagicBase}
 	echo configure options:
-	echo --prefix="${GettextInstallDir}" ${GettextConfigureOptions}
+	echo --prefix="${LibMagicInstallDir}" ${LibMagicConfigureOptions}
 
-	mkdir -p "${GettextBuildDir}" && cd "${GettextBuildDir}"
+	mkdir -p "${LibMagicBuildDir}" && cd "${LibMagicBuildDir}"
 
 	# ----------------------------------------
-	# Build Gettext for different architectures
+	# Build LibMagic for different architectures
 	# ----------------------------------------
-	FILE_LIST="${GettextLibrary}"
+	FILE_LIST="${LibMagicLibrary}"
 
 	for arch in ${ARCH_LIST} ; do
 		CPPFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export CPPFLAGS
 		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export LDFLAGS
-		HOSTSYSTEM=$(eval "echo \\$HostSystem_$arch")
-		"${GettextSourceDir}/configure"\
-			--prefix="${GettextInstallDir}"\
-			${GettextConfigureOptions}
+		"${LibMagicSourceDir}/configure"\
+			--prefix="${LibMagicInstallDir}"\
+			${LibMagicConfigureOptions}
 		make && make install${strip}
 		for file in ${FILE_LIST} ; do
-			if [ -f "${GettextInstallDir}"/lib/${file} ]; then
-				mv "${GettextInstallDir}"/lib/${file}\
-					"${GettextInstallDir}"/lib/${file}-${arch} 
+			if [ -f "${LibMagicInstallDir}"/lib/${file} ]; then
+				mv "${LibMagicInstallDir}"/lib/${file}\
+					"${LibMagicInstallDir}"/lib/${file}-${arch} 
 			else
-				echo Cannot build and install Gettext for ${arch}.
+				echo Cannot build and install LibMagic for ${arch}.
 				exit 1
 			fi
 		done
@@ -429,15 +479,17 @@ if [ -d "${GettextSourceDir}" -a ! -f "${GettextInstallHdr}" ]; then
 			OBJ_LIST="${OBJ_LIST} lib/${file}-${arch}"
 		done
 		(
-			cd "${GettextInstallDir}"
+			cd "${LibMagicInstallDir}"
 			lipo -create ${OBJ_LIST} -o lib/${file}
+			# check for the "missing link"...
+			test -f lib/libmagic.dylib || (cd lib ; ln -s "${LibMagicLibrary}" libmagic.dylib)
 		)
 	done
 	# --------
 	# Clean up
 	# --------
 	for arch in ${ARCH_LIST} ; do
-		rm -f "${GettextInstallDir}"/lib/*-${arch}
+		rm -f "${LibMagicInstallDir}"/lib/*-${arch}
 	done
 fi
 
@@ -466,7 +518,6 @@ if [ -d "${HunSpellSourceDir}" -a ! -f "${HunSpellInstallHdr}" ]; then
 		make distclean
 		CPPFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export CPPFLAGS
 		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export LDFLAGS
-		HOSTSYSTEM=$(eval "echo \\$HostSystem_$arch")
 		"${HunSpellSourceDir}/configure"\
 			--prefix="${HunSpellInstallDir}"\
 			${HunspellConfigureOptions}
@@ -530,7 +581,6 @@ if [ -d "${ASpellSourceDir}" -a ! -f "${ASpellInstallHdr}" -a "yes" = "${aspell_
 		make distclean
 		CPPFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export CPPFLAGS
 		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"; export LDFLAGS
-		HOSTSYSTEM=$(eval "echo \\$HostSystem_$arch")
 		CXXFLAGS=-g "${ASpellSourceDir}/configure"\
 			--prefix="${ASpellInstallDir}"\
 			${AspellConfigureOptions}
@@ -619,13 +669,12 @@ build_lyx() {
 
 		CPPFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"
 		LDFLAGS="${SDKROOT:+-isysroot ${SDKROOT}} -arch ${arch} ${MYCFLAGS}"
-		HOSTSYSTEM=$(eval "echo \\$HostSystem_$arch")
 
-		if [ "$configure_qt4_frameworks" = "yes" ]; then
-			export QT4_CORE_CFLAGS="-FQtCore"
-			export QT4_CORE_LIBS="-framework QtCore"
-			export QT4_FRONTEND_CFLAGS="-FQtGui"
-			export QT4_FRONTEND_LIBS="-framework QtGui"
+		if [ "$configure_qt_frameworks" = "yes" ]; then
+			export QT_CORE_CFLAGS="-FQtCore"
+			export QT_CORE_LIBS="-framework QtCore"
+			export QT_FRONTEND_CFLAGS="-FQtGui"
+			export QT_FRONTEND_LIBS="-framework QtGui"
 			CPPFLAGS="${CPPFLAGS} -I${SDKROOT}/Library/Frameworks/QtCore.framework/Headers"
 			CPPFLAGS="${CPPFLAGS} -I${SDKROOT}/Library/Frameworks/QtGui.framework/Headers"
 		fi
@@ -634,10 +683,10 @@ build_lyx() {
 		export LDFLAGS
 		echo CPPFLAGS="${CPPFLAGS}"
 		export CPPFLAGS
-		echo CONFIGURE_OPTIONS="${LyXConfigureOptions}" ${QtInstallDir:+"--with-qt4-dir=${QtInstallDir}"}
+		echo CONFIGURE_OPTIONS="${LyXConfigureOptions}" ${QtInstallDir:+"--with-qt-dir=${QtInstallDir}"}
 		"${LyxSourceDir}/configure"\
 			--prefix="${LyxAppPrefix}" --with-version-suffix="-${LyXVersionSuffix}"\
-			${QtInstallDir:+"--with-qt4-dir=${QtInstallDir}"} \
+			${QtInstallDir:+"--with-qt-dir=${QtInstallDir}"} \
 			${LyXConfigureOptions}\
 			--enable-build-type=rel && \
 		make ${MAKEJOBS} && make install${strip}
@@ -660,6 +709,11 @@ content_directory() {
 	echo "${content}"
 }
 
+installname() {
+		echo install_name_tool "$@"
+		install_name_tool "$@"
+}
+
 private_framework() {
 	fwdir=$(framework_name "$1")
 	source="$2"
@@ -669,11 +723,9 @@ private_framework() {
 	mkdir -p "${condir}/${fwdir}"
 	if [ ! -f "${condir}/${fwdir}/${libnm}" ]; then
 		cp -p "${source}" "${condir}/${fwdir}"
-		echo Set library id in "${condir}/${fwdir}/${libnm}"
-		install_name_tool -id "@executable_path/../${fwdir}/${libnm}" "${condir}/${fwdir}/${libnm}"
+		installname -id "@executable_path/../${fwdir}/${libnm}" "${condir}/${fwdir}/${libnm}"
 	fi
-	echo Correct library id reference to "${libnm}" in "${target}"
-	install_name_tool -change "${source}" "@executable_path/../${fwdir}/${libnm}" "${target}"
+	installname -change "${source}" "@executable_path/../${fwdir}/${libnm}" "${target}"
 }
 
 deploy_qtlibs() {
@@ -706,16 +758,17 @@ EOF
 		test -d "${condir}/${fwdir}" || (
 			echo Copy framework "${source}/lib/"$(basename "${fwdir}")
 			cp -pR "${source}/lib/"$(basename "${fwdir}") "${condir}/${fwdir}"
-			echo Set library id in "${condir}/${fwdir}/${version}${libnm}"
-			install_name_tool -id "@executable_path/../${fwdir}/${version}${libnm}" "${condir}/${fwdir}/${version}${libnm}"
+			installname -id "@executable_path/../${fwdir}/${version}${libnm}" "${condir}/${fwdir}/${version}${libnm}"
 			find "${condir}/PlugIns" "${condir}/"$(dirname "${fwdir}") -name Headers -prune -o -type f -print | while read filename ; do
 				if [ "${filename}" != "${target}" ]; then
 					otool -L "${filename}" 2>/dev/null | sort -u | while read library ; do
-						# pattern match for: /path/to/qt4/lib/QtGui.framework/Versions/4/QtGui (compatibility version 4.6.0, current version 4.6.2)
+						# pattern match for: /path/to/qt/lib/QtGui.framework/Versions/4/QtGui (compatibility version 4.6.0, current version 4.6.2)
 						case "${library}" in
+						*@rpath/*"${libnm}"*"("*version*")"*)
+							echo rpath based name for ${libnm} is ok.
+							;;
 						*"${libnm}"*"("*version*")"*)
-							echo Correct library id reference to "${libnm}" in "${filename}"
-							install_name_tool -change\
+							installname -change\
 								"${source}/lib/${dirname}/${version}${libnm}"\
 								"@executable_path/../${fwdir}/${version}${libnm}"\
 								"${filename}"
@@ -725,8 +778,7 @@ EOF
 				fi
 			done
 		)
-		echo Correct library id reference to "${libnm}" in "${target}"
-		install_name_tool -change\
+		installname -change\
 			"${source}/lib/${dirname}/${version}${libnm}"\
 			"@executable_path/../${fwdir}/${version}${libnm}"\
 			"${target}"
@@ -753,8 +805,8 @@ convert_universal() {
 		if [ -n "${OBJ_LIST}" ]; then
 			lipo -create ${OBJ_LIST} -o "${BUNDLE_PATH}/${file}"
 		fi
-		if [ -f "${GettextInstallDir}/lib/${GettextLibrary}" -a "yes" = "${gettext_deployment}" ]; then
-			private_framework Gettext "${GettextInstallDir}/lib/${GettextLibrary}" "${LYX_BUNDLE_PATH}/${file}"
+		if [ -f "${LibMagicInstallDir}/lib/${LibMagicLibrary}" -a "yes" = "${libmagic_deployment}" ]; then
+			private_framework LibMagic "${LibMagicInstallDir}/lib/${LibMagicLibrary}" "${LYX_BUNDLE_PATH}/${file}"
 		fi
 		if [ -f "${ASpellInstallDir}/lib/${ASpellLibrary}" -a "yes" = "${aspell_deployment}" ]; then
 			private_framework Aspell "${ASpellInstallDir}/lib/${ASpellLibrary}" "${LYX_BUNDLE_PATH}/${file}"
@@ -762,7 +814,7 @@ convert_universal() {
 		if [ -f "${HunSpellInstallDir}/lib/${HunSpellLibrary}" -a "yes" = "${hunspell_deployment}" ]; then
 			private_framework Hunspell "${HunSpellInstallDir}/lib/${HunSpellLibrary}" "${LYX_BUNDLE_PATH}/${file}"
 		fi
-		if [ -d "${QtInstallDir}/lib/QtCore.framework/Versions/${QtFrameworkVersion}" -a "yes" = "${qt4_deployment}" ]; then
+		if [ -d "${QtInstallDir}/lib/QtCore.framework/Versions/${QtFrameworkVersion}" -a "yes" = "${qt_deployment}" ]; then
 			deploy_qtlibs "${LYX_BUNDLE_PATH}/${file}"
 		fi
 		otool -L "${BUNDLE_PATH}/${file}" | while read reference ; do
@@ -875,7 +927,8 @@ make_dmg() {
 
 	hdiutil create -type SPARSE -size ${DMGSIZE:-"250m"} -fs HFS+ -volname "${LyxBase}" "${DMGNAME}"
 	# Unmount currently mounted disk image
-	test -d /Volumes/"${LyxBase}" && umount /Volumes/"${LyxBase}"
+	mount | grep "${LyxBase}" && umount /Volumes/"${LyxBase}"
+	test -d /Volumes/"${LyxBase}" && rmdir /Volumes/"${LyxBase}"
 
 	# Mount the disk image
 	hdiutil attach "${DMGNAME}.sparseimage"
@@ -915,12 +968,18 @@ build_package() {
 		cd "${LyxAppPrefix}" && zip -r "${LyxAppZip}" .
 	)
 
+	DMGARCH=""
+	for arch in ${ARCH_LIST} ; do
+		DMGARCH="${DMGARCH}-${arch}"
+	done
+	QtDmgArchSuffix=${QtMajorVersion}${DMGARCH}${QtAPI}.dmg
+
 	test -n "${DMGLocation}" && (
 		make_dmg "${DMGLocation}"
-		if [ -d "${QtInstallDir}/lib/QtCore.framework/Versions/${QtFrameworkVersion}" -a "yes" = "${qt4_deployment}" ]; then
-			rm -f "${DMGLocation}/${DMGNAME}+${Qt4DmgSuffix}"
-			echo move to "${DMGLocation}/${DMGNAME}+${Qt4DmgSuffix}"
-			mv "${DMGLocation}/${DMGNAME}.dmg" "${DMGLocation}/${DMGNAME}+${Qt4DmgSuffix}"
+		if [ -d "${QtInstallDir}/lib/QtCore.framework/Versions/${QtFrameworkVersion}" -a "yes" = "${qt_deployment}" ]; then
+			rm -f "${DMGLocation}/${DMGNAME}+${QtDmgArchSuffix}"
+			echo move to "${DMGLocation}/${DMGNAME}+${QtDmgArchSuffix}"
+			mv "${DMGLocation}/${DMGNAME}.dmg" "${DMGLocation}/${DMGNAME}+${QtDmgArchSuffix}"
 		fi
 	)
 }
