@@ -98,10 +98,15 @@ void BufferList::release(Buffer * buf)
 	BufferStorage::iterator const it =
 		find(bstore.begin(), bstore.end(), buf);
 	if (it != bstore.end()) {
+		Buffer const * parent = buf->parent();
 		Buffer * tmp = (*it);
 		bstore.erase(it);
 		LASSERT(tmp, return);
 		delete tmp;
+		if (parent)
+			// If this was a child, update the parent's buffer
+			// to avoid crashes due to dangling pointers (bug 9979)
+			parent->updateBuffer();
 	}
 }
 
@@ -251,13 +256,22 @@ void BufferList::emergencyWriteAll()
 }
 
 
+void BufferList::invalidateConverterCache() const
+{
+	BufferStorage::const_iterator it = bstore.begin();
+	BufferStorage::const_iterator const en = bstore.end();
+	for (; it != en; ++it)
+		(*it)->params().invalidateConverterCache();
+}
+
+
 bool BufferList::exists(FileName const & fname) const
 {
 	return getBuffer(fname) != 0;
 }
 
 
- bool BufferList::isLoaded(Buffer const * b) const
+bool BufferList::isLoaded(Buffer const * b) const
 {
 	if (!b)
 		return false;
@@ -267,6 +281,16 @@ bool BufferList::exists(FileName const & fname) const
 }
 
 
+bool BufferList::isInternal(Buffer const * b) const
+{
+	if (!b)
+		return false;
+	BufferStorage::const_iterator cit =
+		find(binternal.begin(), binternal.end(), b);
+	return cit != binternal.end();
+}
+
+
 bool BufferList::isOthersChild(Buffer * parent, Buffer * child)
 {
 	LASSERT(parent, return false);
