@@ -354,11 +354,16 @@ public:
 	VSpace defskip;
 	PDFOptions pdfoptions;
 	LayoutFileIndex baseClass_;
+	FormatList exportableFormatList;
+	FormatList viewableFormatList;
+	bool isViewCacheValid;
+	bool isExportCacheValid;
 };
 
 
 BufferParams::Impl::Impl()
-	: defskip(VSpace::MEDSKIP), baseClass_(string(""))
+	: defskip(VSpace::MEDSKIP), baseClass_(string("")),
+	  isViewCacheValid(false), isExportCacheValid(false)
 {
 	// set initial author
 	// FIXME UNICODE
@@ -2252,6 +2257,7 @@ void BufferParams::setDocumentClass(DocumentClassConstPtr tc)
 {
 	// evil, but this function is evil
 	doc_class_ = const_pointer_cast<DocumentClass>(tc);
+	invalidateConverterCache();
 }
 
 
@@ -2310,6 +2316,7 @@ void BufferParams::makeDocumentClass(bool const clone)
 	if (!baseClass())
 		return;
 
+	invalidateConverterCache();
 	LayoutModuleList mods;
 	LayoutModuleList::iterator it = layout_modules_.begin();
 	LayoutModuleList::iterator en = layout_modules_.end();
@@ -2394,49 +2401,46 @@ string BufferParams::bufferFormat() const
 }
 
 
-bool BufferParams::isExportable(string const & format) const
+bool BufferParams::isExportable(string const & format, bool need_viewable) const
 {
-	vector<string> backs = backends();
-	for (vector<string>::const_iterator it = backs.begin();
-	     it != backs.end(); ++it)
-		if (theConverters().isReachable(*it, format))
+	FormatList const & formats = exportableFormats(need_viewable);
+	FormatList::const_iterator fit = formats.begin();
+	FormatList::const_iterator end = formats.end();
+	for (; fit != end ; ++fit) {
+		if ((*fit)->name() == format)
 			return true;
+	}
 	return false;
 }
 
 
-vector<Format const *> BufferParams::exportableFormats(bool only_viewable) const
+FormatList const & BufferParams::exportableFormats(bool only_viewable) const
 {
+	FormatList & cached = only_viewable ?
+			pimpl_->viewableFormatList : pimpl_->exportableFormatList;
+	bool & valid = only_viewable ? 
+			pimpl_->isViewCacheValid : pimpl_->isExportCacheValid;
+	if (valid)
+		return cached;
+
 	vector<string> const backs = backends();
 	set<string> excludes;
 	if (useNonTeXFonts) {
 		excludes.insert("latex");
 		excludes.insert("pdflatex");
 	}
-	vector<Format const *> result =
+	FormatList result =
 		theConverters().getReachable(backs[0], only_viewable, true, excludes);
 	for (vector<string>::const_iterator it = backs.begin() + 1;
 	     it != backs.end(); ++it) {
-		vector<Format const *>  r =
-			theConverters().getReachable(*it, only_viewable, false, excludes);
+		FormatList r = theConverters().getReachable(*it, only_viewable, 
+				false, excludes);
 		result.insert(result.end(), r.begin(), r.end());
 	}
-	return result;
-}
-
-
-bool BufferParams::isExportableFormat(string const & format) const
-{
-	typedef vector<Format const *> Formats;
-	Formats formats;
-	formats = exportableFormats(true);
-	Formats::const_iterator fit = formats.begin();
-	Formats::const_iterator end = formats.end();
-	for (; fit != end ; ++fit) {
-		if ((*fit)->name() == format)
-			return true;
-	}
-	return false;
+	sort(result.begin(), result.end(), Format::formatSorter);
+	cached = result;
+	valid = true;
+	return cached;
 }
 
 
@@ -2526,7 +2530,7 @@ string BufferParams::getDefaultOutputFormat() const
 		return default_output_format;
 	if (isDocBook()
 	    || encoding().package() == Encoding::japanese) {
-		vector<Format const *> const formats = exportableFormats(true);
+		FormatList const & formats = exportableFormats(true);
 		if (formats.empty())
 			return string();
 		// return the first we find
@@ -3294,4 +3298,10 @@ vector<CitationStyle> BufferParams::citeStyles() const
 	return styles;
 }
 
+void BufferParams::invalidateConverterCache() const
+{
+	pimpl_->isExportCacheValid = false;
+	pimpl_->isViewCacheValid = false;
+}
+
 } // namespace lyx
