@@ -179,11 +179,9 @@ public:
 	OutputParams::FLAVOR getOutputFlavor(
 		  std::string const & format = std::string()) const;
 	///
-	bool isExportable(std::string const & format) const;
+	bool isExportable(std::string const & format, bool need_viewable) const;
 	///
-	std::vector<Format const *> exportableFormats(bool only_viewable) const;
-	///
-	bool isExportableFormat(std::string const & format) const;
+	std::vector<const Format *> const & exportableFormats(bool only_viewable) const;
 	/// the backends appropriate for use with this document.
 	/// so, e.g., latex is excluded , if we're using non-TeX fonts
 	std::vector<std::string> backends() const;
@@ -504,6 +502,8 @@ public:
 	/// Return true if language could be set to lang,
 	/// otherwise return false and do not change language
 	bool setLanguage(std::string const & lang);
+	///
+	void invalidateConverterCache() const;
 
 private:
 	///
