@@ -421,7 +421,7 @@ int Changes::latexMarkChange(otexstream & os, BufferParams const & bparams,
 		// close \lyxadded or \lyxdeleted
 		os << '}';
 		column++;
-		if (oldChange.type == Change::DELETED)
+		if (oldChange.type == Change::DELETED && !runparams.wasDisplayMath)
 			--runparams.inulemcmd;
 	}
 
@@ -433,7 +433,8 @@ int Changes::latexMarkChange(otexstream & os, BufferParams const & bparams,
 	docstring macro_beg;
 	if (change.type == Change::DELETED) {
 		macro_beg = from_ascii("\\lyxdeleted{");
-		++runparams.inulemcmd;
+		if (!runparams.inDisplayMath)
+			++runparams.inulemcmd;
 	}
 	else if (change.type == Change::INSERTED)
 		macro_beg = from_ascii("\\lyxadded{");
@@ -442,6 +443,17 @@ int Changes::latexMarkChange(otexstream & os, BufferParams const & bparams,
 				       bparams.authors().get(change.author).name(),
 				       chgTime, runparams);
 	
+	// signature needed by \lyxsout to correctly strike out display math
+	if (change.type == Change::DELETED && runparams.inDisplayMath
+	    && (!LaTeXFeatures::isAvailable("dvipost")
+		|| (runparams.flavor != OutputParams::LATEX
+		    && runparams.flavor != OutputParams::DVILUATEX))) {
+		if (os.afterParbreak())
+			str += from_ascii("\\\\\\noindent\n");
+		else
+			str += from_ascii("\\\\\\\\\n");
+	}
+
 	os << str;
 	column += str.size();
 
