@@ -298,7 +298,7 @@ ColorSet::ColorSet()
 	{ Color_paragraphmarker, N_("paragraph marker"), "paragraphmarker", grey80, "paragraphmarker"},
 	{ Color_previewframe, N_("preview frame"), "previewframe", "black", "previewframe"},
 	{ Color_inherit, N_("inherit"), "inherit", "black", "inherit" },
-	{ Color_regexpframe, N_("regexp frame"), "green", "green", "green" },
+	{ Color_regexpframe, N_("regexp frame"), "regexpframe", "green", "regexpframe" },
 	{ Color_ignore, N_("ignore"), "ignore", "black", "ignore" },
 	{ Color_ignore, 0, 0, 0, 0 }
 	};
