@@ -21,16 +21,38 @@ enum ColorCode {
 	///
 	Color_white,
 	///
-	Color_red,
-	///
-	Color_green,
-	///
 	Color_blue,
 	///
+	Color_brown,
+	///
 	Color_cyan,
 	///
+	Color_darkgray,
+	///
+	Color_gray,
+	///
+	Color_green,
+	///
+	Color_lightgray,
+	///
+	Color_lime,
+	///
 	Color_magenta,
 	///
+	Color_olive,
+	///
+	Color_orange,
+	///
+	Color_pink,
+	///
+	Color_purple,
+	///
+	Color_red,
+	///
+	Color_teal,
+	///
+	Color_violet,
+	///
 	Color_yellow,
 
 	// Needed interface colors
@@ -91,6 +113,8 @@ enum ColorCode {
 
 	/// Color for the depth bars in the margin
 	Color_depthbar,
+	/// Color that indicates when a row can be scrolled
+	Color_scroll,
 	/// Color for marking foreign language words
 	Color_language,
 
