@@ -72,10 +72,14 @@ enchant::Dict * EnchantChecker::Private::addSpeller(string const & lang)
 	Speller m;
 
 	try {
+		LYXERR(Debug::FILES, "request enchant speller for language " << lang);
 		m.speller = instance->request_dict(lang);
 	}
-	catch (const enchant::Exception & e) {
+	catch (enchant::Exception & e) {
 		// FIXME error handling?
+		const char * what = e.what();
+		LYXERR(Debug::FILES, "cannot add enchant speller: " <<
+			   ((what && *what) ? what : "unspecified enchant exception in request_dict()"));
 		m.speller = 0;
 	}
 	spellers_[lang] = m;
