@@ -14,6 +14,7 @@
 #define ENCODING_H
 
 #include "support/docstring.h"
+#include "support/trivstring.h"
 #include "support/types.h"
 
 #include <map>
@@ -29,7 +30,7 @@ public:
 	EncodingException(char_type c);
 	virtual ~EncodingException() throw() {}
 	virtual const char * what() const throw();
- 
+
 	char_type failed_char;
 	int par_id;
 	pos_type pos;
@@ -51,17 +52,19 @@ enum CharInfoFlags {
 	CharInfoMathNoTermination = 32,
 	///
 	CharInfoForceSelected = 64,
+	///
+	CharInfoDeprecated = 128
 };
 
 
 /// Information about a single UCS4 character
 class CharInfo {
 public:
-	CharInfo() {}
+	CharInfo() : flags_(0) {}
 	CharInfo(
-		docstring const textcommand, docstring const mathcommand,
-		std::string const textpreamble, std::string const mathpreamble,
-		std::string const tipashortcut, unsigned int flags);
+		docstring const & textcommand, docstring const & mathcommand,
+		std::string const & textpreamble, std::string const & mathpreamble,
+		std::string const & tipashortcut, unsigned int flags);
 	// we assume that at least one command is nonempty when using unicodesymbols
 	bool isUnicodeSymbol() const { return !textcommand_.empty() || !mathcommand_.empty(); }
 	/// LaTeX command (text mode) for this character
@@ -85,6 +88,8 @@ public:
 	bool force() const { return flags_ & CharInfoForce ? true : false; }
 	/// Force the LaTeX command for some encodings?
 	bool forceselected() const { return flags_ & CharInfoForceSelected ? true : false; }
+	/// Disable LaTeX command => char_type conversion for this deprecated symbol?
+	bool deprecated() const { return flags_ & CharInfoDeprecated ? true : false; }
 	/// TIPA shortcut
 	std::string const tipashortcut() const { return tipashortcut_; }
 	/// \c textcommand needs no termination (such as {} or space).
@@ -94,21 +99,25 @@ public:
 	///
 private:
 	/// LaTeX command (text mode) for this character
-	docstring textcommand_;
+	trivdocstring textcommand_;
 	/// LaTeX command (math mode) for this character
-	docstring mathcommand_;
+	trivdocstring mathcommand_;
 	/// Needed LaTeX preamble (or feature) for text mode
-	std::string textpreamble_;
+	trivstring textpreamble_;
 	/// Needed LaTeX preamble (or feature) for math mode
-	std::string mathpreamble_;
+	trivstring mathpreamble_;
 	/// TIPA shortcut
-	std::string tipashortcut_;
+	trivstring tipashortcut_;
 	/// feature flags
 	unsigned int flags_;
 };
 
 
-///
+/**
+ * An encoding as defined in lib/encodings.
+ * All const methods are thread-safe, so the caller does not need any locking.
+ * This property must be kept when changing the class.
+ */
 class Encoding {
 public:
 	/// Which LaTeX package handles this encoding?
@@ -121,7 +130,8 @@ public:
 	/// Represent any of the above packages
 	static int const any;
 	///
-	Encoding() {}
+	Encoding() : fixedwidth_(true), unsafe_(false), start_encodable_(0),
+	             package_(none), complete_(false) {}
 	///
 	Encoding(std::string const & n, std::string const & l,
 		 std::string const & g, std::string const & i,
@@ -129,13 +139,13 @@ public:
 	///
 	void init() const;
 	///
-	std::string const & name() const { return name_; }
+	std::string const name() const { return name_; }
 	///
-	std::string const & latexName() const { return latexName_; }
+	std::string const latexName() const { return latexName_; }
 	///
-	std::string const & guiName() const { return guiName_; }
+	std::string const guiName() const { return guiName_; }
 	///
-	std::string const & iconvName() const { return iconvName_; }
+	std::string const iconvName() const { return iconvName_; }
 	///
 	bool hasFixedWidth() const { return fixedwidth_; }
 	///
@@ -164,7 +174,7 @@ public:
 	 * \p dryrun specifies whether the string is used within source
 	 * preview (which yields a special warning).
 	 */
-	std::pair<docstring, docstring> latexString(docstring const input,
+	std::pair<docstring, docstring> latexString(docstring const & input,
 						    bool dryrun = false) const;
 	/// Which LaTeX package handles this encoding?
 	Package package() const { return package_; }
@@ -178,13 +188,13 @@ private:
 	 */
 	bool isForced(char_type c) const;
 	///
-	std::string name_;
+	trivstring name_;
 	///
-	std::string latexName_;
+	trivstring latexName_;
 	///
-	std::string guiName_;
+	trivstring guiName_;
 	///
-	std::string iconvName_;
+	trivstring iconvName_;
 	/// Is this a fixed width encoding?
 	bool fixedwidth_;
 	/// Is this encoding TeX unsafe, e.g. control characters like {, }
@@ -194,13 +204,13 @@ private:
 	typedef std::set<char_type> CharSet;
 	/// Set of UCS4 characters that we can encode (for singlebyte
 	/// encodings only)
-	mutable CharSet encodable_;
+	CharSet encodable_;
 	/// Set of UCS4 characters that we can't encode
 	CharSet const * forced_;
 	/// All code points below this are encodable. This helps us to avoid
 	/// lokup of ASCII characters in encodable_ and gives about 1 sec
 	/// speedup on export of the Userguide.
-	mutable char_type start_encodable_;
+	char_type start_encodable_;
 	/// Which LaTeX package handles this encoding?
 	Package package_;
 	/**
@@ -210,7 +220,7 @@ private:
 	 * This is needed especially for the multibyte encodings, if we
 	 * complete all encoding info on startup it takes 2-3 minutes.
 	 */
-	mutable bool complete_;
+	bool complete_;
 };
 
 class Encodings {
@@ -222,7 +232,7 @@ public:
 	///
 	typedef std::set<char_type> MathSymbolSet;
 	///
-	typedef std::map<std::string, Encoding> EncodingList;
+	typedef std::map<trivstring, Encoding> EncodingList;
 	/// iterator to iterate over all encodings.
 	/// We hide the fact that our encoding list is implemented as a map.
 	class const_iterator : public EncodingList::const_iterator {
@@ -255,29 +265,8 @@ public:
 	///
 	const_iterator end() const { return encodinglist.end(); }
 
-	///
-	enum LetterForm {
-		///
-		FORM_ISOLATED,
-		///
-		FORM_FINAL,
-		///
-		FORM_INITIAL,
-		///
-		FORM_MEDIAL
-	};
-	///
-	static bool isHebrewComposeChar(char_type c);
-	///
-	static bool isArabicComposeChar(char_type c);
-	///
-	static bool isArabicSpecialChar(char_type c);
-	///
-	static bool isArabicChar(char_type c);
 	/// Accessor for the unicode information table.
 	static CharInfo const & unicodeCharInfo(char_type c);
-	///
-	static char_type transformChar(char_type c, LetterForm form);
 	/// Is this a combining char?
 	static bool isCombiningChar(char_type c);
 	/// Return the TIPA shortcut
