@@ -286,7 +286,7 @@ int Font::latexWriteStartChanges(odocstream & os, BufferParams const & bparams,
 			tmp += "{";
 			os << from_ascii(tmp);
 			count += tmp.length();
-			pushPolyglossiaLang(language()->polyglossia(), true);
+			pushLanguageName(language()->polyglossia(), true);
 		} else if (language()->encoding()->package() != Encoding::CJK) {
 			os << '{';
 			count += 1;
@@ -322,6 +322,8 @@ int Font::latexWriteStartChanges(odocstream & os, BufferParams const & bparams,
 				      "$$lang", language()->babel());
 			os << from_ascii(tmp);
 			count += tmp.length();
+			if (!lyxrc.language_command_end.empty())
+				pushLanguageName(language()->babel(), true);
 		} else if (language()->encoding()->package() != Encoding::CJK) {
 			os << '{';
 			count += 1;
@@ -447,6 +449,7 @@ int Font::latexWriteEndChanges(otexstream & os, BufferParams const & bparams,
 				  OutputParams const & runparams,
 				  Font const & base,
 				  Font const & next,
+				  bool & needPar,
 				  bool const & closeLanguage) const
 {
 	int count = 0;
@@ -491,6 +494,11 @@ int Font::latexWriteEndChanges(otexstream & os, BufferParams const & bparams,
 	if (f.size() != FONT_SIZE_INHERIT) {
 		// We only have to close if only size changed
 		if (!env) {
+			if (needPar && !closeLanguage) {
+				os << "\\par";
+				count += 4;
+				needPar = false;
+			}
 			os << '}';
 			++count;
 		}
@@ -545,8 +553,11 @@ int Font::latexWriteEndChanges(otexstream & os, BufferParams const & bparams,
 	    && language()->encoding()->package() != Encoding::CJK) {
 		os << '}';
 		++count;
-		if (runparams.use_polyglossia)
-			popPolyglossiaLang();
+		bool const using_begin_end =
+			runparams.use_polyglossia ||
+				!lyxrc.language_command_end.empty();
+		if (using_begin_end)
+			popLanguageName();
 	}
 
 	return count;
