@@ -778,6 +778,12 @@ int LaTeX::scanLogFile(TeXErrors & terr)
 				}
 			}
 
+			if (prefixIs(token, "! Incomplete \\if")) {
+				// bug 10666. At this point its not clear we finish with error.
+				wait_for_error = desc;
+				continue;
+			}
+
 			if (prefixIs(token, "! Paragraph ended before \\Hy@setref@link was complete.")){
 					// bug 7344. We must rerun LaTeX if hyperref has been toggled.
 					retval |= ERROR_RERUN;
@@ -881,8 +887,16 @@ int LaTeX::scanLogFile(TeXErrors & terr)
 			} else if (contains(token, "No pages of output")) {
 				// A dvi file was not created
 				retval |= NO_OUTPUT;
+			} else if (contains(token, "Error 256 (driver return code)")) {
+				// This is a xdvipdfmx driver error reported by XeTeX.
+				// We have to check whether an output PDF file was created.
+				FileName pdffile = file;
+				pdffile.changeExtension("pdf");
+				if (!pdffile.exists())
+					// No output PDF file was created (see #10076)
+					retval |= NO_OUTPUT;
 			} else if (contains(token, "That makes 100 errors")) {
-				// More than 100 errors were reprted
+				// More than 100 errors were reported
 				retval |= TOO_MANY_ERRORS;
 			} else if (prefixIs(token, "!pdfTeX error:")) {
 				// otherwise we dont catch e.g.:
@@ -897,11 +911,18 @@ int LaTeX::scanLogFile(TeXErrors & terr)
 				// Warning about missing glyph in selected font
 				// may be dataloss (bug 9610)
 				// but can be ignored for 'nullfont' (bug 10394).
-				retval |= LATEX_ERROR;
-				terr.insertError(0,
-						 from_local8bit("Missing glyphs!"),
-						 from_local8bit(token),
-						 child_name);
+				// as well as for ZERO WIDTH NON-JOINER (0x200C) which is
+				// missing in many fonts and output for ligature break (bug 10727).
+				// Since this error only occurs with utf8 output, we can safely assume
+				// that the log file is utf8-encoded
+				docstring const utoken = from_utf8(token);
+				if (!contains(utoken, 0x200C)) {
+					retval |= LATEX_ERROR;
+					terr.insertError(0,
+							 from_ascii("Missing glyphs!"),
+							 utoken,
+							 child_name);
+				}
 			}
 		}
 	}
