@@ -19,7 +19,6 @@
 #include "support/docstring.h"
 #include "support/FileName.h"
 
-#include <boost/noncopyable.hpp>
 #include <boost/signal.hpp>
 
 #include <vector>
@@ -45,7 +44,7 @@ private:
 			  error_desc(desc),
 			  error_text(text),
 			  child_name(fname) {}
-		/// what line in the TeX file the error occured in
+		/// what line in the TeX file the error occurred in
 		int error_in_line;
 		/// The kind of error
 		docstring error_desc;
@@ -65,6 +64,8 @@ public:
 	void insertError(int line, docstring const & error_desc,
 			 docstring const & error_text,
 			 std::string const & child_name = empty_string());
+	///
+	void clearErrors() { errors.clear(); }
 private:
 	///
 	Errors errors;
@@ -98,7 +99,7 @@ bool operator!=(AuxInfo const &, AuxInfo const &);
  * This is required by the LaTeX compiler, and we also make use of it by
  * various support::makeAbsPath() calls.
  */
-class LaTeX : boost::noncopyable {
+class LaTeX {
 public:
 	/** Return values from scanLogFile() and run() (to come)
 
@@ -139,10 +140,9 @@ public:
 		///
 		BIBTEX_ERROR = 16384,
 		///
-		//FIXME: BIBTEX_ERROR has been removed from ERRORS for now, since users were irritated
-		//       about those errors which prevented compilation of previously compiling documents.
-		//       Think about a "gentle" transfer to BibTeX error reporting.
-		ERRORS = TEX_ERROR + LATEX_ERROR,
+		NONZERO_ERROR = 32768, // the command exited with nonzero status
+		///
+		ERRORS = TEX_ERROR + LATEX_ERROR + NONZERO_ERROR + BIBTEX_ERROR,
 		///
 		WARNINGS = TEX_WARNING + LATEX_WARNING + PACKAGE_WARNING
 	};
@@ -153,11 +153,17 @@ public:
 
 	/**
 	   cmd = the latex command, file = name of the (temporary) latex file,
-	   path = name of the files original path.
+	   path = name of the files original path,
+	   clean_start = This forces a fresh run by deleting the files in the temp
+			 dir. We set this e.g. if there was an error on previous
+			 preview, which is good if the user installed a package
+			 or changed certain document settings (#9061).
 	*/
 	LaTeX(std::string const & cmd, OutputParams const &,
 	      support::FileName const & file,
-	      std::string const & path = empty_string());
+	      std::string const & path = empty_string(),
+	      std::string const & lpath = empty_string(),
+	      bool const clean_start = false);
 
 	/// runs LaTeX several times
 	int run(TeXErrors &);
@@ -169,6 +175,10 @@ public:
 	int scanLogFile(TeXErrors &);
 
 private:
+	/// noncopyable
+	LaTeX(LaTeX const &);
+	void operator=(LaTeX const &);
+
 	/// use this for running LaTeX once
 	int startscript();
 
@@ -207,7 +217,7 @@ private:
 		       OutputParams const &);
 
 	///
-	void deleteFilesOnError() const;
+	void removeAuxiliaryFiles() const;
 
 	///
 	std::string cmd;
@@ -215,9 +225,12 @@ private:
 	///
 	support::FileName file;
 
-	///
+	/// The document directory path.
 	std::string path;
 
+	/// Extra path, possibly relative to the document directory path.
+	std::string lpath;
+
 	/// used by scanLogFile
 	int num_errors;
 
