@@ -18,6 +18,7 @@
 
 #include "LyXRC.h"
 
+#include "BufferList.h"
 #include "ColorSet.h"
 #include "Converter.h"
 #include "FontEnums.h"
@@ -1226,6 +1227,7 @@ LyXRC::ReturnValues LyXRC::read(Lexer & lexrc, bool check_format)
 	/// Update converters data-structures
 	theConverters().update(formats);
 	theConverters().buildGraph();
+	theBufferList().invalidateConverterCache();
 
 	return ReadOK;
 }
@@ -1311,7 +1313,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_DEFFILE:
 		if (ignore_system_lyxrc ||
 		    def_file != system_lyxrc.def_file) {
@@ -1328,7 +1330,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		   << "# MISC SECTION ######################################\n"
 		   << "#\n\n";
 		// bind files are not done here.
-
+		// fall through
 	case RC_PATH_PREFIX:
 		if (ignore_system_lyxrc ||
 		    path_prefix != system_lyxrc.path_prefix) {
@@ -1336,6 +1338,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_UIFILE:
 		if (ignore_system_lyxrc ||
 		    ui_file != system_lyxrc.ui_file) {
@@ -1344,6 +1347,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_AUTOREGIONDELETE:
 		if (ignore_system_lyxrc ||
 		    auto_region_delete != system_lyxrc.auto_region_delete) {
@@ -1354,6 +1358,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_AUTORESET_OPTIONS:
 		if (ignore_system_lyxrc ||
 		    auto_reset_options != system_lyxrc.auto_reset_options) {
@@ -1365,6 +1370,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_AUTOSAVE:
 		if (ignore_system_lyxrc ||
 		    autosave != system_lyxrc.autosave) {
@@ -1373,6 +1379,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_DISPLAY_GRAPHICS:
 		if (ignore_system_lyxrc ||
 		    display_graphics != system_lyxrc.display_graphics) {
@@ -1384,6 +1391,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SORT_LAYOUTS:
 		if (ignore_system_lyxrc ||
 		    sort_layouts != system_lyxrc.sort_layouts) {
@@ -1392,6 +1400,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_GROUP_LAYOUTS:
 		if (ignore_system_lyxrc ||
 		    group_layouts != system_lyxrc.group_layouts) {
@@ -1400,6 +1409,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_VIEWDVI_PAPEROPTION:
 		if (ignore_system_lyxrc ||
 		    view_dvi_paper_option
@@ -1411,6 +1421,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_CHKTEX_COMMAND:
 		if (ignore_system_lyxrc ||
 		    chktex_command != system_lyxrc.chktex_command) {
@@ -1418,6 +1429,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_BIBTEX_ALTERNATIVES: {
 		CommandSet::const_iterator it = bibtex_alternatives.begin();
 		CommandSet::const_iterator end = bibtex_alternatives.end();
@@ -1430,6 +1442,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		if (tag != RC_LAST)
 			break;
 	}
+	// fall through
 	case RC_BIBTEX_COMMAND:
 		if (ignore_system_lyxrc ||
 		    bibtex_command != system_lyxrc.bibtex_command) {
@@ -1437,6 +1450,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_JBIBTEX_COMMAND:
 		if (ignore_system_lyxrc ||
 		    jbibtex_command != system_lyxrc.jbibtex_command) {
@@ -1444,6 +1458,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_INDEX_ALTERNATIVES: {
 		CommandSet::const_iterator it = index_alternatives.begin();
 		CommandSet::const_iterator end = index_alternatives.end();
@@ -1456,6 +1471,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		if (tag != RC_LAST)
 			break;
 	}
+	// fall through
 	case RC_INDEX_COMMAND:
 		if (ignore_system_lyxrc ||
 		    index_command != system_lyxrc.index_command) {
@@ -1463,6 +1479,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_JINDEX_COMMAND:
 		if (ignore_system_lyxrc ||
 		    jindex_command != system_lyxrc.jindex_command) {
@@ -1470,6 +1487,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SPLITINDEX_COMMAND:
 		if (ignore_system_lyxrc ||
 		    splitindex_command != system_lyxrc.splitindex_command) {
@@ -1477,6 +1495,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_NOMENCL_COMMAND:
 		if (ignore_system_lyxrc ||
 		    nomencl_command != system_lyxrc.nomencl_command) {
@@ -1484,6 +1503,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_TEX_EXPECTS_WINDOWS_PATHS:
 		// Don't write this setting to the preferences file,
 		// but allow temporary changes (bug 7557).
@@ -1493,6 +1513,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_TEX_ALLOWS_SPACES:
 		if (tex_allows_spaces != system_lyxrc.tex_allows_spaces) {
 			os << "\\tex_allows_spaces "
@@ -1500,6 +1521,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_KBMAP:
 		if (ignore_system_lyxrc ||
 		    use_kbmap != system_lyxrc.use_kbmap) {
@@ -1507,6 +1529,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_KBMAP_PRIMARY:
 		if (ignore_system_lyxrc ||
 		    primary_kbmap != system_lyxrc.primary_kbmap) {
@@ -1515,6 +1538,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_KBMAP_SECONDARY:
 		if (ignore_system_lyxrc ||
 		    secondary_kbmap != system_lyxrc.secondary_kbmap) {
@@ -1523,6 +1547,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SERVERPIPE:
 		if (ignore_system_lyxrc ||
 		    lyxpipes != system_lyxrc.lyxpipes) {
@@ -1531,6 +1556,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_DATE_INSERT_FORMAT:
 		if (ignore_system_lyxrc ||
 		    date_insert_format != system_lyxrc.date_insert_format) {
@@ -1539,17 +1565,17 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_USER_NAME:
 		os << "\\user_name \"" << user_name << "\"\n";
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_USER_EMAIL:
 		os << "\\user_email \"" << user_email << "\"\n";
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_SHOW_BANNER:
 		if (ignore_system_lyxrc ||
 		    show_banner != system_lyxrc.show_banner) {
@@ -1557,7 +1583,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_PREVIEW:
 		if (ignore_system_lyxrc ||
 		    preview != system_lyxrc.preview) {
@@ -1577,7 +1603,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_PREVIEW_HASHED_LABELS:
 		if (ignore_system_lyxrc ||
 		    preview_hashed_labels !=
@@ -1587,7 +1613,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_PREVIEW_SCALE_FACTOR:
 		if (ignore_system_lyxrc ||
 		    preview_scale_factor != system_lyxrc.preview_scale_factor) {
@@ -1596,7 +1622,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_USE_CONVERTER_CACHE:
 		if (ignore_system_lyxrc ||
 		    use_converter_cache != system_lyxrc.use_converter_cache) {
@@ -1606,6 +1632,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		if (tag != RC_LAST)
 			break;
 
+		// fall through
 	case RC_CONVERTER_CACHE_MAXAGE:
 		if (ignore_system_lyxrc ||
 		    converter_cache_maxage != system_lyxrc.converter_cache_maxage) {
@@ -1618,7 +1645,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		os << "\n#\n"
 		   << "# SCREEN & FONTS SECTION ############################\n"
 		   << "#\n\n";
-
+		// fall through
 	case RC_ICON_SET:
 		if (ignore_system_lyxrc ||
 		    icon_set != system_lyxrc.icon_set) {
@@ -1627,7 +1654,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_USE_SYSTEM_THEME_ICONS:
 		if (ignore_system_lyxrc ||
 			  use_system_theme_icons != system_lyxrc.use_system_theme_icons) {
@@ -1637,7 +1664,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_SCREEN_DPI:
 		if (ignore_system_lyxrc ||
 		    dpi != system_lyxrc.dpi) {
@@ -1645,6 +1672,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SCREEN_ZOOM:
 		if (ignore_system_lyxrc ||
 		    zoom != system_lyxrc.zoom) {
@@ -1652,6 +1680,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_GEOMETRY_SESSION:
 		if (ignore_system_lyxrc ||
 		    allow_geometry_session != system_lyxrc.allow_geometry_session) {
@@ -1660,6 +1689,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_CURSOR_FOLLOWS_SCROLLBAR:
 		if (ignore_system_lyxrc ||
 		    cursor_follows_scrollbar
@@ -1669,6 +1699,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_CURSOR_WIDTH:
 		if (ignore_system_lyxrc ||
 			cursor_width
@@ -1678,6 +1709,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SCROLL_BELOW_DOCUMENT:
 		if (ignore_system_lyxrc ||
 		    scroll_below_document
@@ -1687,6 +1719,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_PARAGRAPH_MARKERS:
 		if (ignore_system_lyxrc ||
 			paragraph_markers
@@ -1696,6 +1729,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_MAC_DONTSWAP_CTRL_META:
 		if (ignore_system_lyxrc ||
 		    mac_dontswap_ctrl_meta
@@ -1705,6 +1739,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_MAC_LIKE_CURSOR_MOVEMENT:
 		if (ignore_system_lyxrc ||
 		    mac_like_cursor_movement
@@ -1714,6 +1749,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_MACRO_EDIT_STYLE:
 		if (ignore_system_lyxrc ||
 		    macro_edit_style
@@ -1727,6 +1763,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_DIALOGS_ICONIFY_WITH_MAIN:
 		if (ignore_system_lyxrc ||
 		    dialogs_iconify_with_main
@@ -1736,6 +1773,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SCREEN_FONT_ROMAN:
 		if (ignore_system_lyxrc ||
 		    roman_font_name != system_lyxrc.roman_font_name) {
@@ -1744,6 +1782,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SCREEN_FONT_ROMAN_FOUNDRY:
 		if (ignore_system_lyxrc ||
 		    roman_font_foundry != system_lyxrc.roman_font_foundry) {
@@ -1752,6 +1791,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SCREEN_FONT_SANS:
 		if (ignore_system_lyxrc ||
 		    sans_font_name != system_lyxrc.sans_font_name) {
@@ -1760,6 +1800,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SCREEN_FONT_SANS_FOUNDRY:
 		if (ignore_system_lyxrc ||
 		    sans_font_foundry != system_lyxrc.sans_font_foundry) {
@@ -1768,6 +1809,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SCREEN_FONT_TYPEWRITER:
 		if (ignore_system_lyxrc ||
 		    typewriter_font_name != system_lyxrc.typewriter_font_name) {
@@ -1776,6 +1818,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SCREEN_FONT_TYPEWRITER_FOUNDRY:
 		if (ignore_system_lyxrc ||
 		    typewriter_font_foundry != system_lyxrc.typewriter_font_foundry) {
@@ -1784,7 +1827,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_SCREEN_FONT_SCALABLE:
 		if (ignore_system_lyxrc ||
 		    use_scalable_fonts != system_lyxrc.use_scalable_fonts) {
@@ -1794,6 +1837,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SCREEN_FONT_SIZES:
 		if (ignore_system_lyxrc ||
 		    font_sizes[FONT_SIZE_TINY]
@@ -1836,6 +1880,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_FULL_SCREEN_LIMIT:
 		if (ignore_system_lyxrc ||
 		    full_screen_limit != system_lyxrc.full_screen_limit) {
@@ -1845,6 +1890,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_FULL_SCREEN_TOOLBARS:
 		if (ignore_system_lyxrc ||
 		    full_screen_toolbars != system_lyxrc.full_screen_toolbars) {
@@ -1854,6 +1900,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_FULL_SCREEN_SCROLLBAR:
 		if (ignore_system_lyxrc ||
 		    full_screen_scrollbar != system_lyxrc.full_screen_scrollbar) {
@@ -1863,6 +1910,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_FULL_SCREEN_STATUSBAR:
 		if (ignore_system_lyxrc ||
 		    full_screen_statusbar != system_lyxrc.full_screen_statusbar) {
@@ -1872,6 +1920,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_FULL_SCREEN_TABBAR:
 		if (ignore_system_lyxrc ||
 		    full_screen_tabbar != system_lyxrc.full_screen_tabbar) {
@@ -1881,6 +1930,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_FULL_SCREEN_MENUBAR:
 		if (ignore_system_lyxrc ||
 		    full_screen_menubar != system_lyxrc.full_screen_menubar) {
@@ -1890,6 +1940,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_FULL_SCREEN_WIDTH:
 		if (ignore_system_lyxrc ||
 		    full_screen_width != system_lyxrc.full_screen_width) {
@@ -1899,6 +1950,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_OPEN_BUFFERS_IN_TABS:
 		if (ignore_system_lyxrc ||
 		    open_buffers_in_tabs != system_lyxrc.open_buffers_in_tabs) {
@@ -1908,6 +1960,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SINGLE_CLOSE_TAB_BUTTON:
 		if (ignore_system_lyxrc ||
 		    single_close_tab_button != system_lyxrc.single_close_tab_button) {
@@ -1917,6 +1970,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SINGLE_INSTANCE:
 		if (ignore_system_lyxrc ||
 		    single_instance != system_lyxrc.single_instance) {
@@ -1926,6 +1980,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_FORWARD_SEARCH_DVI:
 		if (ignore_system_lyxrc ||
 		    forward_search_dvi != system_lyxrc.forward_search_dvi) {
@@ -1933,6 +1988,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_FORWARD_SEARCH_PDF:
 		if (ignore_system_lyxrc ||
 		    forward_search_pdf != system_lyxrc.forward_search_pdf) {
@@ -1945,6 +2001,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 			<< "# COLOR SECTION ###################################\n"
 			<< "#\n\n";
 
+	// fall through
 	case RC_SET_COLOR:
 		for (int i = 0; i < Color_ignore; ++i) {
 			ColorCode lc = static_cast<ColorCode>(i);
@@ -1963,6 +2020,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		 << "# PRINTER SECTION ###################################\n"
 		 << "#\n\n";
 
+	// fall through
 	case RC_PRINTLANDSCAPEFLAG:
 		if (ignore_system_lyxrc ||
 		    print_landscape_flag != system_lyxrc.print_landscape_flag) {
@@ -1971,7 +2029,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_PRINTPAPERFLAG:
 		if (ignore_system_lyxrc ||
 		    print_paper_flag != system_lyxrc.print_paper_flag) {
@@ -1980,7 +2038,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_PRINTPAPERDIMENSIONFLAG:
 		if (ignore_system_lyxrc ||
 		    print_paper_dimension_flag
@@ -1995,6 +2053,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		 << "# TEX SECTION #######################################\n"
 		 << "#\n\n";
 
+	// fall through
 	case RC_TEXINPUTS_PREFIX:
 		if (ignore_system_lyxrc ||
 		    texinputs_prefix != system_lyxrc.texinputs_prefix) {
@@ -2002,7 +2061,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_FONT_ENCODING:
 		if (ignore_system_lyxrc ||
 		    fontenc != system_lyxrc.fontenc) {
@@ -2015,6 +2074,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		   << "# FILE SECTION ######################################\n"
 		   << "#\n\n";
 
+	// fall through
 	case RC_DOCUMENTPATH:
 		if (ignore_system_lyxrc ||
 		    document_path != system_lyxrc.document_path) {
@@ -2023,6 +2083,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_USELASTFILEPOS:
 		if (ignore_system_lyxrc ||
 		    use_lastfilepos != system_lyxrc.use_lastfilepos) {
@@ -2031,6 +2092,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_LOADSESSION:
 		if (ignore_system_lyxrc ||
 		    load_session != system_lyxrc.load_session) {
@@ -2039,6 +2101,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_MOUSE_WHEEL_SPEED:
 		if (ignore_system_lyxrc ||
 		    mouse_wheel_speed != system_lyxrc.mouse_wheel_speed) {
@@ -2046,6 +2109,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_MOUSE_MIDDLEBUTTON_PASTE:
 		if (ignore_system_lyxrc ||
 		    mouse_middlebutton_paste != system_lyxrc.mouse_middlebutton_paste) {
@@ -2054,6 +2118,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_INLINE_DELAY:
 		if (ignore_system_lyxrc ||
 		    completion_inline_delay != system_lyxrc.completion_inline_delay) {
@@ -2061,6 +2126,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_INLINE_MATH:
 		if (ignore_system_lyxrc ||
 		    completion_inline_math != system_lyxrc.completion_inline_math) {
@@ -2069,6 +2135,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_INLINE_TEXT:
 		if (ignore_system_lyxrc ||
 		    completion_inline_text != system_lyxrc.completion_inline_text) {
@@ -2077,6 +2144,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_INLINE_DOTS:
 		if (ignore_system_lyxrc ||
 		    completion_inline_dots != system_lyxrc.completion_inline_dots) {
@@ -2085,6 +2153,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_AUTOCORRECTION_MATH:
 		if (ignore_system_lyxrc ||
 		    autocorrection_math != system_lyxrc.autocorrection_math) {
@@ -2093,6 +2162,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_POPUP_DELAY:
 		if (ignore_system_lyxrc ||
 		    completion_popup_delay != system_lyxrc.completion_popup_delay) {
@@ -2100,6 +2170,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_POPUP_MATH:
 		if (ignore_system_lyxrc ||
 		    completion_popup_math != system_lyxrc.completion_popup_math) {
@@ -2108,6 +2179,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_POPUP_TEXT:
 		if (ignore_system_lyxrc ||
 		    completion_popup_text != system_lyxrc.completion_popup_text) {
@@ -2116,6 +2188,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_CURSOR_TEXT:
 		if (ignore_system_lyxrc ||
 		    completion_cursor_text != system_lyxrc.completion_cursor_text) {
@@ -2124,6 +2197,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_POPUP_AFTER_COMPLETE:
 		if (ignore_system_lyxrc ||
 		    completion_popup_after_complete
@@ -2133,6 +2207,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_COMPLETION_MINLENGTH:
 		if (ignore_system_lyxrc ||
 			completion_minlength != system_lyxrc.completion_minlength) {
@@ -2141,14 +2216,15 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
-		case RC_NUMLASTFILES:
+		// fall through
+	case RC_NUMLASTFILES:
 		if (ignore_system_lyxrc ||
 		    num_lastfiles != system_lyxrc.num_lastfiles) {
 			os << "\\num_lastfiles " << num_lastfiles << '\n';
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_CHECKLASTFILES:
 		if (ignore_system_lyxrc ||
 		    check_lastfiles != system_lyxrc.check_lastfiles) {
@@ -2157,6 +2233,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_EXAMPLEPATH:
 		if (ignore_system_lyxrc ||
 		    example_path != system_lyxrc.example_path) {
@@ -2165,6 +2242,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_TEMPLATEPATH:
 		if (ignore_system_lyxrc ||
 		    template_path != system_lyxrc.template_path) {
@@ -2173,6 +2251,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_TEMPDIRPATH:
 		if (ignore_system_lyxrc ||
 		    tempdir_path != system_lyxrc.tempdir_path) {
@@ -2181,6 +2260,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_THESAURUSDIRPATH:
 		if (ignore_system_lyxrc ||
 		    thesaurusdir_path != system_lyxrc.thesaurusdir_path) {
@@ -2189,6 +2269,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_HUNSPELLDIR_PATH:
 		if (ignore_system_lyxrc ||
 		    hunspelldir_path != system_lyxrc.hunspelldir_path) {
@@ -2197,6 +2278,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_PLAINTEXT_LINELEN:
 		if (ignore_system_lyxrc ||
 		    plaintext_linelen != system_lyxrc.plaintext_linelen) {
@@ -2204,6 +2286,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_MAKE_BACKUP:
 		if (ignore_system_lyxrc ||
 		    make_backup != system_lyxrc.make_backup) {
@@ -2211,6 +2294,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SAVE_COMPRESSED:
 		if (ignore_system_lyxrc ||
 		    save_compressed != system_lyxrc.save_compressed) {
@@ -2218,6 +2302,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_SAVE_ORIGIN:
 		if (ignore_system_lyxrc ||
 		    save_origin != system_lyxrc.save_origin) {
@@ -2225,6 +2310,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_BACKUPDIR_PATH:
 		if (ignore_system_lyxrc ||
 		    backupdir_path != system_lyxrc.backupdir_path) {
@@ -2242,6 +2328,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		   << "# SPELLCHECKER SECTION ##############################\n"
 		   << "#\n\n";
 
+	// fall through
 	case RC_ACCEPT_COMPOUND:
 		if (ignore_system_lyxrc ||
 		    spellchecker_accept_compound != system_lyxrc.spellchecker_accept_compound) {
@@ -2250,6 +2337,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_ALT_LANG:
 		if (ignore_system_lyxrc ||
 		    spellchecker_alt_lang != system_lyxrc.spellchecker_alt_lang) {
@@ -2258,6 +2346,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_ESC_CHARS:
 		if (ignore_system_lyxrc ||
 		    spellchecker_esc_chars != system_lyxrc.spellchecker_esc_chars) {
@@ -2265,6 +2354,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_USE_SYSTEM_COLORS:
 		if (ignore_system_lyxrc ||
 		    use_system_colors != system_lyxrc.use_system_colors) {
@@ -2274,6 +2364,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_USE_TOOLTIP:
 		if (ignore_system_lyxrc ||
 		    use_tooltip != system_lyxrc.use_tooltip) {
@@ -2283,6 +2374,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_USE_PIXMAP_CACHE:
 		if (ignore_system_lyxrc ||
 		    use_pixmap_cache != system_lyxrc.use_pixmap_cache) {
@@ -2292,6 +2384,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_USE_QIMAGE:
 		if (ignore_system_lyxrc ||
 		    use_qimage != system_lyxrc.use_qimage) {
@@ -2306,6 +2399,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		   << "# LANGUAGE SUPPORT SECTION ##########################\n"
 		   << "#\n\n";
 
+	// fall through
 	case RC_DEFAULT_DECIMAL_POINT:
 		if (ignore_system_lyxrc ||
 		    default_decimal_point != system_lyxrc.default_decimal_point) {
@@ -2313,7 +2407,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_DEFAULT_LENGTH_UNIT:
 		if (ignore_system_lyxrc ||
 		    default_length_unit != system_lyxrc.default_length_unit) {
@@ -2321,7 +2415,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_SPELLCHECKER:
 		if (ignore_system_lyxrc ||
 		    spellchecker != system_lyxrc.spellchecker) {
@@ -2329,7 +2423,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_SPELLCHECK_CONTINUOUSLY:
 		if (ignore_system_lyxrc ||
 		    spellcheck_continuously != system_lyxrc.spellcheck_continuously) {
@@ -2338,7 +2432,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_SPELLCHECK_NOTES:
 		if (ignore_system_lyxrc ||
 		    spellcheck_notes != system_lyxrc.spellcheck_notes) {
@@ -2347,7 +2441,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_VISUAL_CURSOR:
 		if (ignore_system_lyxrc ||
 			visual_cursor != system_lyxrc.visual_cursor) {
@@ -2355,6 +2449,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_CLOSE_BUFFER_WITH_LAST_VIEW:
 		if (ignore_system_lyxrc ||
 			close_buffer_with_last_view != system_lyxrc.close_buffer_with_last_view) {
@@ -2363,6 +2458,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_LANGUAGE_CUSTOM_PACKAGE:
 		if (ignore_system_lyxrc ||
 		    language_custom_package != system_lyxrc.language_custom_package) {
@@ -2371,6 +2467,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_LANGUAGE_GLOBAL_OPTIONS:
 		if (ignore_system_lyxrc ||
 		    language_global_options
@@ -2381,6 +2478,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_LANGUAGE_PACKAGE_SELECTION:
 		if (ignore_system_lyxrc ||
 		    language_package_selection != system_lyxrc.language_package_selection) {
@@ -2402,6 +2500,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_LANGUAGE_COMMAND_BEGIN:
 		if (ignore_system_lyxrc ||
 		    language_command_begin
@@ -2412,6 +2511,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_LANGUAGE_COMMAND_END:
 		if (ignore_system_lyxrc ||
 		    language_command_end
@@ -2421,6 +2521,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_LANGUAGE_COMMAND_LOCAL:
 		if (ignore_system_lyxrc ||
 		    language_command_local
@@ -2431,6 +2532,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_LANGUAGE_AUTO_BEGIN:
 		if (ignore_system_lyxrc ||
 		    language_auto_begin != system_lyxrc.language_auto_begin) {
@@ -2439,6 +2541,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_LANGUAGE_AUTO_END:
 		if (ignore_system_lyxrc ||
 		    language_auto_end != system_lyxrc.language_auto_end) {
@@ -2447,6 +2550,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_MARK_FOREIGN_LANGUAGE:
 		if (ignore_system_lyxrc ||
 		    mark_foreign_language
@@ -2461,6 +2565,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		   << "# 2nd MISC SUPPORT SECTION ##########################\n"
 		   << "#\n\n";
 
+	// fall through
 	case RC_AUTO_NUMBER:
 		if (ignore_system_lyxrc ||
 		    auto_number != system_lyxrc.auto_number) {
@@ -2468,6 +2573,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_GUI_LANGUAGE:
 		if (ignore_system_lyxrc ||
 		    gui_language != system_lyxrc.gui_language) {
@@ -2475,6 +2581,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_EXPORT_OVERWRITE:
 		if (ignore_system_lyxrc ||
 		    export_overwrite != system_lyxrc.export_overwrite) {
@@ -2494,7 +2601,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_SCROLL_WHEEL_ZOOM:
 		if (ignore_system_lyxrc ||
 			scroll_wheel_zoom != system_lyxrc.scroll_wheel_zoom) {
@@ -2522,6 +2629,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		   << "# FORMATS SECTION ##########################\n"
 		   << "#\n\n";
 
+	// fall through
 	case RC_FILEFORMAT:
 		// New/modified formats
 		for (Formats::const_iterator cit = formats.begin();
@@ -2567,6 +2675,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 				   << "\" \"\" \"\" \"\" \"\" \"\" \"\" \"\"\n";
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_VIEWER_ALTERNATIVES: {
 		Alternatives::const_iterator it = viewer_alternatives.begin();
 		Alternatives::const_iterator const en = viewer_alternatives.end();
@@ -2592,6 +2701,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		if (tag != RC_LAST)
 			break;
 	}
+	// fall through
 	case RC_EDITOR_ALTERNATIVES: {
 		Alternatives::const_iterator it = editor_alternatives.begin();
 		Alternatives::const_iterator const en = editor_alternatives.end();
@@ -2617,6 +2727,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		if (tag != RC_LAST)
 			break;
 	}
+	// fall through
 	case RC_DEFAULT_OTF_VIEW_FORMAT:
 		if ((ignore_system_lyxrc ||
 		     default_otf_view_format != system_lyxrc.default_otf_view_format)
@@ -2625,6 +2736,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_DEFAULT_VIEW_FORMAT:
 		if (ignore_system_lyxrc ||
 		    default_view_format != system_lyxrc.default_view_format) {
@@ -2632,6 +2744,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		}
 		if (tag != RC_LAST)
 			break;
+		// fall through
 	case RC_VIEWER:
 		// Ignore it
 		if (tag != RC_LAST)
@@ -2641,6 +2754,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 		   << "# CONVERTERS SECTION ##########################\n"
 		   << "#\n\n";
 
+	// fall through
 	case RC_CONVERTER:
 		// Look for new converters
 		for (Converters::const_iterator cit = theConverters().begin();
@@ -2665,7 +2779,7 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc, string const & name) c
 				   << "\" \"" << cit->to() << "\" \"\" \"\"\n";
 		if (tag != RC_LAST)
 			break;
-
+		// fall through
 	case RC_COPIER:
 		if (tag == RC_LAST)
 			os << "\n#\n"
