@@ -99,14 +99,13 @@ pos_type Row::Element::x2pos(int &x) const
 	case SPACE:
 		// those elements contain only one position. Round to
 		// the closest side.
-		if (x > full_width()) {
+		if (x > (full_width() + 1) / 2) {
 			x = int(full_width());
 			i = !isRTL();
 		} else {
 			x = 0;
 			i = isRTL();
 		}
-
 	}
 	//lyxerr << "=> p=" << pos + i << " x=" << x << endl;
 	return pos + i;
