@@ -93,7 +93,7 @@ FontInfo RowPainter::labelFont() const
 {
 	FontInfo f = text_.labelFont(par_);
 	// selected text?
-	if (row_.begin_margin_sel || pi_.selected)
+	if ((row_.selection() && row_.begin_margin_sel) || pi_.selected)
 		f.setPaintColor(Color_selectiontext);
 	return f;
 }
@@ -687,8 +687,9 @@ void RowPainter::paintSelection() const
 			double x2 = e.pos2x(to);
 			if (x1 > x2)
 				swap(x1, x2);
-			pi_.pain.fillRectangle(int(x + x1), y1, int(x2 - x1), y2 - y1,
-			                       Color_selection);
+			// the 3rd argument is written like that to avoid rounding issues
+			pi_.pain.fillRectangle(int(x + x1), y1, int(x2 + x) - int(x1 + x),
+			                       y2 - y1, Color_selection);
 		}
 		x += e.full_width();
 	}
