@@ -421,10 +421,21 @@ bool TextMetrics::redoParagraph(pit_type const pit)
 				parPos.pos()++;
 		}
 
+		// If there is an end of paragraph marker, its size should be
+		// substracted to the available width. The logic here is
+		// almost the same as in breakRow, remember keep them in sync.
+		int eop = 0;
+		if (lyxrc.paragraph_markers && ii->pos + 1 == par.size()
+		    && size_type(pit + 1) < text_->paragraphs().size()) {
+			Font f(text_->layoutFont(pit));
+			// ¶ U+00B6 PILCROW SIGN
+			eop = theFontMetrics(f).width(char_type(0x00B6));
+		}
+
 		// do the metric calculation
 		Dimension dim;
 		int const w = max_width_ - leftMargin(max_width_, pit, ii->pos)
-			- right_margin;
+			- right_margin - eop;
 		Font const & font = ii->inset->inheritFont() ?
 			displayFont(pit, ii->pos) : bufferfont;
 		MacroContext mc(&buffer, parPos);
@@ -807,8 +818,6 @@ void TextMetrics::breakRow(Row & row, int const right_margin, pit_type const pit
 	// the width available for the row.
 	int const width = max_width_ - row.right_margin;
 
-	ParagraphList const & pars = text_->paragraphs();
-
 #if 0
 	//FIXME: As long as leftMargin() is not correctly implemented for
 	// MARGIN_RIGHT_ADDRESS_BOX, we should also not do this here.
@@ -916,7 +925,9 @@ void TextMetrics::breakRow(Row & row, int const right_margin, pit_type const pit
 	row.finalizeLast();
 	row.endpos(i);
 
-	// End of paragraph marker
+	// End of paragraph marker. The logic here is almost the
+	// same as in redoParagraph, remember keep them in sync.
+	ParagraphList const & pars = text_->paragraphs();
 	if (lyxrc.paragraph_markers && !need_new_row
 	    && i == end && size_type(pit + 1) < pars.size()) {
 		// add a virtual element for the end-of-paragraph
@@ -936,7 +947,8 @@ void TextMetrics::breakRow(Row & row, int const right_margin, pit_type const pit
 	int const next_width = max_width_ - leftMargin(max_width_, pit, row.endpos())
 		- rightMargin(pit);
 
-	row.shortenIfNeeded(body_pos, width, next_width);
+	if (row.shortenIfNeeded(body_pos, width, next_width))
+		row.flushed(false);
 	row.right_boundary(!row.empty() && row.endpos() < end
 	                   && row.back().endpos == row.endpos());
 	// Last row in paragraph is flushed
@@ -1181,8 +1193,10 @@ pos_type TextMetrics::getPosNearX(Row const & row, int & x,
 		 * how boundary helps here.
 		 */
 		else if (pos == cit->endpos
-			 && cit + 1 != row.end()
-			 && cit->isRTL() != (cit + 1)->isRTL())
+		         && ((!cit->isRTL() && cit + 1 != row.end()
+		              && (cit + 1)->isRTL())
+		             || (cit->isRTL() && cit != row.begin()
+		                 && !(cit - 1)->isRTL())))
 			boundary = true;
 	}
 
@@ -1369,23 +1383,19 @@ Inset * TextMetrics::editXY(Cursor & cur, int x, int y,
 	}
 	pit_type pit = getPitNearY(y);
 	LASSERT(pit != -1, return 0);
-
-	int yy = y; // is modified by getPitAndRowNearY
-	Row const & row = getPitAndRowNearY(yy, pit, assert_in_view, up);
-
+	Row const & row = getPitAndRowNearY(y, pit, assert_in_view, up);
 	cur.pit() = pit;
 
 	// Do we cover an inset?
-	InsetList::InsetTable * it = checkInsetHit(pit, x, yy);
+	InsetList::InsetTable * it = checkInsetHit(pit, x, y);
 
 	if (!it) {
 		// No inset, set position in the text
 		bool bound = false; // is modified by getPosNearX
-		int xx = x; // is modified by getPosNearX
-		cur.pos() = getPosNearX(row, xx, bound);
+		cur.pos() = getPosNearX(row, x, bound);
 		cur.boundary(bound);
 		cur.setCurrentFont();
-		cur.setTargetX(xx);
+		cur.setTargetX(x);
 		return 0;
 	}
 
@@ -1398,23 +1408,17 @@ Inset * TextMetrics::editXY(Cursor & cur, int x, int y,
 	cur.setTargetX(x);
 
 	// Try to descend recursively inside the inset.
-	Inset * edited = inset->editXY(cur, x, yy);
-	if (edited == inset && cur.pos() == it->pos) {
+	Inset * edited = inset->editXY(cur, x, y);
+	// FIXME: it is not clear that the test on position is needed
+	// Remove it if/when semantics of editXY is clarified
+	if (cur.text() == text_ && cur.pos() == it->pos) {
 		// non-editable inset, set cursor after the inset if x is
 		// nearer to that position (bug 9628)
-		CoordCache::Insets const & insetCache = bv_->coordCache().getInsets();
-		Dimension const & dim = insetCache.dim(inset);
-		Point p = insetCache.xy(inset);
-		bool const is_rtl = text_->isRTL(text_->getPar(pit));
-		if (is_rtl) {
-			// "in front of" == "right of"
-			if (abs(p.x_ - x) < abs(p.x_ + dim.wid - x))
-				cur.posForward();
-		} else {
-			// "in front of" == "left of"
-			if (abs(p.x_ + dim.wid - x) < abs(p.x_ - x))
-				cur.posForward();
-		}
+		bool bound = false; // is modified by getPosNearX
+		cur.pos() = getPosNearX(row, x, bound);
+		cur.boundary(bound);
+		cur.setCurrentFont();
+		cur.setTargetX(x);
 	}
 
 	if (cur.top().text() == text_)
