@@ -13,6 +13,7 @@
 
 #include "VCBackend.h"
 #include "Buffer.h"
+#include "DispatchResult.h"
 #include "LyX.h"
 #include "FuncRequest.h"
 
@@ -27,6 +28,7 @@
 #include "support/PathChanger.h"
 #include "support/Systemcall.h"
 #include "support/regex.h"
+#include "support/TempFile.h"
 
 #include <fstream>
 
@@ -42,7 +44,7 @@ int VCS::doVCCommandCall(string const & cmd, FileName const & path)
 	LYXERR(Debug::LYXVC, "doVCCommandCall: " << cmd);
 	Systemcall one;
 	support::PathChanger p(path);
-	return one.startscript(Systemcall::Wait, cmd, string(), false);
+	return one.startscript(Systemcall::Wait, cmd, string(), string(), false);
 }
 
 
@@ -57,7 +59,7 @@ int VCS::doVCCommand(string const & cmd, FileName const & path, bool reportError
 		owner_->setBusy(false);
 	if (ret && reportError)
 		frontend::Alert::error(_("Revision control error."),
-			bformat(_("Some problem occured while running the command:\n"
+			bformat(_("Some problem occurred while running the command:\n"
 				  "'%1$s'."),
 			from_utf8(cmd)));
 	return ret;
@@ -73,8 +75,8 @@ bool VCS::makeRCSRevision(string const &version, string &revis) const
 		// if positive use as the last number in the whole revision string
 		if (back > 0) {
 			string base;
-			rsplit(version, base , '.' );
-			rev = base + "." + rev;
+			rsplit(version, base , '.');
+			rev = base + '.' + rev;
 		}
 		if (back == 0)
 			rev = version;
@@ -82,14 +84,14 @@ bool VCS::makeRCSRevision(string const &version, string &revis) const
 		// in case of backward indexing
 		if (back < 0) {
 			string cur, base;
-			cur = rsplit(version, base , '.' );
+			cur = rsplit(version, base , '.');
 			if (!isStrInt(cur))
 				return false;
 			int want = convert<int>(cur) + back;
 			if (want <= 0)
 				return false;
-			
-			rev = base + "." + convert<string>(want);
+
+			rev = base + '.' + convert<string>(want);
 		}
 	}
 
@@ -292,7 +294,8 @@ bool RCS::isCheckInWithConfirmation()
 	// if (getDiff(file, diff) && diff.empty())
 	//	return false;
 
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return true;
@@ -303,7 +306,6 @@ bool RCS::isCheckInWithConfirmation()
 		FileName(owner_->filePath()));
 
 	docstring diff = tmpf.fileContents("UTF-8");
-	tmpf.removeFile();
 
 	if (diff.empty())
 		return false;
@@ -358,7 +360,7 @@ bool RCS::lockingToggleEnabled()
 
 bool RCS::revert()
 {
-	if (doVCCommand("co -f -u" + version_ + " "
+	if (doVCCommand("co -f -u" + version_ + ' '
 		    + quoteName(onlyFileName(owner_->absFileName())),
 		    FileName(owner_->filePath())))
 		return false;
@@ -378,7 +380,7 @@ bool RCS::isRevertWithConfirmation()
 void RCS::undoLast()
 {
 	LYXERR(Debug::LYXVC, "LyXVC: undoLast");
-	doVCCommand("rcs -o" + version_ + " "
+	doVCCommand("rcs -o" + version_ + ' '
 		    + quoteName(onlyFileName(owner_->absFileName())),
 		    FileName(owner_->filePath()));
 }
@@ -433,7 +435,8 @@ string RCS::revisionInfo(LyXVC::RevisionInfo const info)
 
 bool RCS::getRevisionInfo()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
@@ -480,16 +483,19 @@ bool RCS::prepareFileRevision(string const &revis, string & f)
 	if (!VCS::makeRCSRevision(version_, rev))
 		return false;
 
-	FileName tmpf = FileName::tempName("lyxvcrev_" + rev + "_");
+	TempFile tempfile("lyxvcrev_" + rev + '_');
+	tempfile.setAutoRemove(false);
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
 	}
 
-	doVCCommand("co -p" + rev + " "
+	doVCCommand("co -p" + rev + ' '
 	              + quoteName(onlyFileName(owner_->absFileName()))
 		      + " > " + quoteName(tmpf.toFilesystemEncoding()),
 		FileName(owner_->filePath()));
+	tmpf.refresh();
 	if (tmpf.isFileEmpty())
 		return false;
 
@@ -634,7 +640,7 @@ docstring CVS::toString(CvsStatus status) const
 	case StatusError:
 		return _("Cannot retrieve CVS status");
 	}
-	return 0;
+	return docstring();
 }
 
 
@@ -657,7 +663,8 @@ int CVS::doVCCommandCallWithOutput(std::string const & cmd,
 
 CVS::CvsStatus CVS::getStatus()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return StatusError;
@@ -665,7 +672,6 @@ CVS::CvsStatus CVS::getStatus()
 
 	if (doVCCommandCallWithOutput("cvs status " + getTarget(File),
 		FileName(owner_->filePath()), tmpf)) {
-		tmpf.removeFile();
 		return StatusError;
 	}
 
@@ -675,7 +681,7 @@ CVS::CvsStatus CVS::getStatus()
 	while (ifs) {
 		string line;
 		getline(ifs, line);
-		LYXERR(Debug::LYXVC, line << "\n");
+		LYXERR(Debug::LYXVC, line << '\n');
 		if (prefixIs(line, "File:")) {
 			if (contains(line, "Up-to-date"))
 				status = UpToDate;
@@ -689,7 +695,6 @@ CVS::CvsStatus CVS::getStatus()
 				status = NeedsCheckout;
 		}
 	}
-	tmpf.removeFile();
 	return status;
 }
 
@@ -698,28 +703,28 @@ void CVS::getRevisionInfo()
 	if (have_rev_info_)
 		return;
 	have_rev_info_ = true;
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return;
 	}
-	
-	int rc = doVCCommandCallWithOutput("cvs log -r" + version_ 
-		+ " " + getTarget(File),
+
+	int rc = doVCCommandCallWithOutput("cvs log -r" + version_
+		+ ' ' + getTarget(File),
 		FileName(owner_->filePath()), tmpf);
 	if (rc) {
-		tmpf.removeFile();
 		LYXERR(Debug::LYXVC, "cvs log failed with exit code " << rc);
 		return;
 	}
-	
+
 	ifstream ifs(tmpf.toFilesystemEncoding().c_str());
 	static regex const reg("date: (.*) (.*) (.*);  author: (.*);  state: (.*);(.*)");
 
 	while (ifs) {
 		string line;
 		getline(ifs, line);
-		LYXERR(Debug::LYXVC, line << "\n");
+		LYXERR(Debug::LYXVC, line << '\n');
 		if (prefixIs(line, "date:")) {
 			smatch sm;
 			regex_match(line, sm, reg);
@@ -731,7 +736,6 @@ void CVS::getRevisionInfo()
 			break;
 		}
 	}
-	tmpf.removeFile();
 	if (rev_author_cache_.empty())
 		LYXERR(Debug::LYXVC,
 		   "Could not retrieve revision info for " << version_ <<
@@ -824,7 +828,7 @@ string CVS::scanLogFile(FileName const & f, string & status)
 	while (ifs) {
 		string line;
 		getline(ifs, line);
-		LYXERR(Debug::LYXVC, line << "\n");
+		LYXERR(Debug::LYXVC, line << '\n');
 		if (!line.empty())
 			status += line + "; ";
 		if (prefixIs(line, "C ")) {
@@ -902,12 +906,13 @@ string CVS::checkOut()
 {
 	if (vcstatus != NOLOCKING && edit())
 		return string();
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return string();
 	}
-	
+
 	int rc = update(File, tmpf);
 	string log;
 	string const res = scanLogFile(tmpf, log);
@@ -919,8 +924,7 @@ string CVS::checkOut()
 				from_local8bit(res)));
 		rc = 0;
 	}
-	
-	tmpf.removeFile();
+
 	return rc ? string() : log.empty() ? "CVS: Proceeded" : "CVS: " + log;
 }
 
@@ -936,12 +940,13 @@ bool CVS::checkOutEnabled()
 
 string CVS::repoUpdate()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return string();
 	}
-	
+
 	getDiff(Directory, tmpf);
 	docstring res = tmpf.fileContents("UTF-8");
 	if (!res.empty()) {
@@ -953,16 +958,14 @@ string CVS::repoUpdate()
 				"or you will need to revert back to the repository version."), file);
 		int ret = frontend::Alert::prompt(_("Changes detected"),
 				text, 0, 1, _("&Continue"), _("&Abort"), _("View &Log ..."));
-		if (ret == 2 ) {
+		if (ret == 2) {
 			dispatch(FuncRequest(LFUN_DIALOG_SHOW, "file " + tmpf.absFileName()));
 			ret = frontend::Alert::prompt(_("Changes detected"),
 				text, 0, 1, _("&Continue"), _("&Abort"));
 			hideDialogs("file", 0);
 		}
-		if (ret == 1 ) {
-			tmpf.removeFile();
+		if (ret == 1)
 			return string();
-		}
 	}
 
 	int rc = update(Directory, tmpf);
@@ -980,8 +983,6 @@ string CVS::repoUpdate()
 				file, from_local8bit(sres)));
 		rc = 0;
 	}
-	
-	tmpf.removeFile();
 
 	return rc ? string() : log.empty() ? "CVS: Proceeded" : "CVS: " + log;
 }
@@ -1108,15 +1109,18 @@ bool CVS::prepareFileRevision(string const & revis, string & f)
 	if (!VCS::makeRCSRevision(version_, rev))
 		return false;
 
-	FileName tmpf = FileName::tempName("lyxvcrev_" + rev + "_");
+	TempFile tempfile("lyxvcrev_" + rev + '_');
+	tempfile.setAutoRemove(false);
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
 	}
 
-	doVCCommandWithOutput("cvs update -p -r" + rev + " "
+	doVCCommandWithOutput("cvs update -p -r" + rev + ' '
 		+ getTarget(File),
 		FileName(owner_->filePath()), tmpf);
+	tmpf.refresh();
 	if (tmpf.isFileEmpty())
 		return false;
 
@@ -1156,7 +1160,8 @@ FileName const SVN::findFile(FileName const & file)
 	}
 
 	// Now we check the status of the file.
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return FileName();
@@ -1167,7 +1172,6 @@ FileName const SVN::findFile(FileName const & file)
 	bool found = 0 == doVCCommandCall("svn info " + quoteName(fname)
 						+ " > " + quoteName(tmpf.toFilesystemEncoding()),
 						file.onlyPath());
-	tmpf.removeFile();
 	LYXERR(Debug::LYXVC, "SVN control: " << (found ? "enabled" : "disabled"));
 	return found ? file : FileName();
 }
@@ -1189,7 +1193,8 @@ void SVN::scanMaster()
 
 bool SVN::checkLockMode()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()){
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
@@ -1319,7 +1324,8 @@ LyXVC::CommandResult SVN::checkIn(string const & msg, string & log)
 LyXVC::CommandResult
 SVN::checkIn(vector<support::FileName> const & f, string const & msg, string & log)
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()){
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		log = N_("Error: Could not generate logfile.");
@@ -1347,7 +1353,6 @@ SVN::checkIn(vector<support::FileName> const & f, string const & msg, string & l
 		if (!fileLock(false, tmpf, log))
 			ret = LyXVC::ErrorCommand;
 
-	tmpf.removeFile();
 	if (!log.empty())
 		log.insert(0, "SVN: ");
 	if (ret == LyXVC::VCSuccess && log.empty())
@@ -1369,7 +1374,8 @@ bool SVN::isCheckInWithConfirmation()
 {
 	// FIXME one day common getDiff and perhaps OpMode for all backends
 
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return true;
@@ -1380,7 +1386,6 @@ bool SVN::isCheckInWithConfirmation()
 		FileName(owner_->filePath()));
 
 	docstring diff = tmpf.fileContents("UTF-8");
-	tmpf.removeFile();
 
 	if (diff.empty())
 		return false;
@@ -1399,8 +1404,8 @@ string SVN::scanLogFile(FileName const & f, string & status)
 
 	while (ifs) {
 		getline(ifs, line);
-		LYXERR(Debug::LYXVC, line << "\n");
-		if (!line.empty()) 
+		LYXERR(Debug::LYXVC, line << '\n');
+		if (!line.empty())
 			status += line + "; ";
 		if (prefixIs(line, "C ") || prefixIs(line, "CU ")
 					 || contains(line, "Commit failed")) {
@@ -1455,7 +1460,8 @@ bool SVN::fileLock(bool lock, FileName const & tmpf, string &status)
 
 string SVN::checkOut()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return N_("Error: Could not generate logfile.");
@@ -1476,7 +1482,6 @@ string SVN::checkOut()
 
 	fileLock(true, tmpf, log);
 
-	tmpf.removeFile();
 	return log.empty() ? string() : "SVN: " + log;
 }
 
@@ -1492,7 +1497,8 @@ bool SVN::checkOutEnabled()
 
 string SVN::repoUpdate()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return N_("Error: Could not generate logfile.");
@@ -1512,16 +1518,14 @@ string SVN::repoUpdate()
 				"\n\nContinue?"), file);
 		int ret = frontend::Alert::prompt(_("Changes detected"),
 				text, 0, 1, _("&Yes"), _("&No"), _("View &Log ..."));
-		if (ret == 2 ) {
+		if (ret == 2) {
 			dispatch(FuncRequest(LFUN_DIALOG_SHOW, "file " + tmpf.absFileName()));
 			ret = frontend::Alert::prompt(_("Changes detected"),
 				text, 0, 1, _("&Yes"), _("&No"));
 			hideDialogs("file", 0);
 		}
-		if (ret == 1 ) {
-			tmpf.removeFile();
+		if (ret == 1)
 			return string();
-		}
 	}
 
 	// Reverting looks too harsh, see bug #6255.
@@ -1535,7 +1539,6 @@ string SVN::repoUpdate()
 	res += "Update log:\n" + tmpf.fileContents("UTF-8");
 
 	LYXERR(Debug::LYXVC, res);
-	tmpf.removeFile();
 	return to_utf8(res);
 }
 
@@ -1548,7 +1551,8 @@ bool SVN::repoUpdateEnabled()
 
 string SVN::lockingToggle()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return N_("Error: Could not generate logfile.");
@@ -1576,9 +1580,8 @@ string SVN::lockingToggle()
 	if (ret)
 		return string();
 
-	tmpf.removeFile();
 	frontend::Alert::warning(_("SVN File Locking"),
-		(locking ? _("Locking property unset.") : _("Locking property set.")) + "\n"
+		(locking ? _("Locking property unset.") : _("Locking property set.")) + '\n'
 		+ _("Do not forget to commit the locking property into the repository."),
 		true);
 
@@ -1667,7 +1670,8 @@ string SVN::revisionInfo(LyXVC::RevisionInfo const info)
 
 bool SVN::getFileRevisionInfo()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
@@ -1713,14 +1717,14 @@ bool SVN::getFileRevisionInfo()
 	}
 
 	ifs.close();
-	tmpf.removeFile();
 	return !rev.empty();
 }
 
 
 bool SVN::getTreeRevisionInfo()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
@@ -1737,7 +1741,6 @@ bool SVN::getTreeRevisionInfo()
 	string line;
 	getline(ifs, line);
 	ifs.close();
-	tmpf.removeFile();
 
 	rev_tree_cache_ = line;
 	return !line.empty();
@@ -1771,16 +1774,19 @@ bool SVN::prepareFileRevision(string const & revis, string & f)
 	}
 
 	string revname = convert<string>(rev);
-	FileName tmpf = FileName::tempName("lyxvcrev_" + revname + "_");
+	TempFile tempfile("lyxvcrev_" + revname + '_');
+	tempfile.setAutoRemove(false);
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
 	}
 
-	doVCCommand("svn cat -r " + revname + " "
+	doVCCommand("svn cat -r " + revname + ' '
 	              + quoteName(onlyFileName(owner_->absFileName()))
 		      + " > " + quoteName(tmpf.toFilesystemEncoding()),
 		FileName(owner_->filePath()));
+	tmpf.refresh();
 	if (tmpf.isFileEmpty())
 		return false;
 
@@ -1826,7 +1832,8 @@ FileName const GIT::findFile(FileName const & file)
 	}
 
 	// Now we check the status of the file.
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return FileName();
@@ -1839,8 +1846,8 @@ FileName const GIT::findFile(FileName const & file)
 			quoteName(fname) + " > " +
 			quoteName(tmpf.toFilesystemEncoding()),
 			file.onlyPath());
+	tmpf.refresh();
 	bool found = !tmpf.isFileEmpty();
-	tmpf.removeFile();
 	LYXERR(Debug::LYXVC, "GIT control: " << (found ? "enabled" : "disabled"));
 	return found ? file : FileName();
 }
@@ -1934,7 +1941,8 @@ LyXVC::CommandResult GIT::checkIn(string const & msg, string & log)
 LyXVC::CommandResult
 GIT::checkIn(vector<support::FileName> const & f, string const & msg, string & log)
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()){
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		log = N_("Error: Could not generate logfile.");
@@ -1959,7 +1967,6 @@ GIT::checkIn(vector<support::FileName> const & f, string const & msg, string & l
 		ret = LyXVC::ErrorCommand;
 	}
 
-	tmpf.removeFile();
 	if (!log.empty())
 		log.insert(0, "GIT: ");
 	if (ret == LyXVC::VCSuccess && log.empty())
@@ -1978,7 +1985,8 @@ bool GIT::isCheckInWithConfirmation()
 {
 	// FIXME one day common getDiff and perhaps OpMode for all backends
 
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return true;
@@ -1989,7 +1997,6 @@ bool GIT::isCheckInWithConfirmation()
 		FileName(owner_->filePath()));
 
 	docstring diff = tmpf.fileContents("UTF-8");
-	tmpf.removeFile();
 
 	if (diff.empty())
 		return false;
@@ -2009,7 +2016,7 @@ string GIT::scanLogFile(FileName const & f, string & status)
 	while (ifs) {
 		getline(ifs, line);
 		LYXERR(Debug::LYXVC, line << "\n");
-		if (!line.empty()) 
+		if (!line.empty())
 			status += line + "; ";
 		if (prefixIs(line, "C ") || prefixIs(line, "CU ")
 					 || contains(line, "Commit failed")) {
@@ -2132,7 +2139,8 @@ string GIT::revisionInfo(LyXVC::RevisionInfo const info)
 
 bool GIT::getFileRevisionInfo()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
@@ -2158,14 +2166,14 @@ bool GIT::getFileRevisionInfo()
 	}
 
 	ifs.close();
-	tmpf.removeFile();
 	return !rev_file_cache_.empty();
 }
 
 
 bool GIT::getTreeRevisionInfo()
 {
-	FileName tmpf = FileName::tempName("lyxvcout");
+	TempFile tempfile("lyxvcout");
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
@@ -2181,7 +2189,6 @@ bool GIT::getTreeRevisionInfo()
 	ifstream ifs(tmpf.toFilesystemEncoding().c_str());
 	getline(ifs, rev_tree_cache_);
 	ifs.close();
-	tmpf.removeFile();
 
 	return !rev_tree_cache_.empty();
 }
@@ -2216,9 +2223,11 @@ bool GIT::prepareFileRevision(string const & revis, string & f)
 	else
 		pointer = revis;
 
-	pointer += ":";
+	pointer += ':';
 
-	FileName tmpf = FileName::tempName("lyxvcrev_" + revis + "_");
+	TempFile tempfile("lyxvcrev_" + revis + '_');
+	tempfile.setAutoRemove(false);
+	FileName tmpf = tempfile.name();
 	if (tmpf.empty()) {
 		LYXERR(Debug::LYXVC, "Could not generate logfile " << tmpf);
 		return false;
@@ -2228,6 +2237,7 @@ bool GIT::prepareFileRevision(string const & revis, string & f)
 	              + quoteName(onlyFileName(owner_->absFileName()))
 		      + " > " + quoteName(tmpf.toFilesystemEncoding()),
 		FileName(owner_->filePath()));
+	tmpf.refresh();
 	if (tmpf.isFileEmpty())
 		return false;
 
@@ -2244,7 +2254,7 @@ bool GIT::prepareFileRevisionEnabled()
 
 bool GIT::toggleReadOnlyEnabled()
 {
-	return false;
+	return true;
 }
 
 
