@@ -35,6 +35,7 @@
 #include "BufferView.h"
 #include "CmdDef.h"
 #include "Color.h"
+#include "Converter.h"
 #include "CutAndPaste.h"
 #include "ErrorList.h"
 #include "Font.h"
@@ -184,6 +185,12 @@ frontend::Application * createApplication(int & argc, char * argv[])
 		}
 	}
 #endif
+
+#if defined(Q_OS_WIN) || defined(Q_CYGWIN_WIN)
+	// On Windows, allow bringing the LyX window to top
+	AllowSetForegroundWindow(ASFW_ANY);
+#endif
+
 	frontend::GuiApplication * guiApp = new frontend::GuiApplication(argc, argv);
 	// I'd rather do that in the constructor, but I do not think that
 	// the palette is accessible there.
@@ -235,6 +242,17 @@ vector<string> loadableImageFormats()
 		// special case
 		if (ext == "jpeg")
 			ext = "jpg";
+		else if (lyxrc.use_converter_cache
+		         && (ext == "svg" || ext == "svgz")
+		         && theConverters().isReachable("svg", "png"))
+			// Qt only supports SVG 1.2 tiny. See #9778. We prefer
+			// displaying the SVG as in the output. However we
+			// require that the converter cache is enabled since
+			// this is expensive. We also require that an explicit
+			// svg->png converter is defined, since the default
+			// converter could produce bad quality as well.
+			// This assumes that png can always be loaded.
+			continue;
 		fmts.push_back(ext);
 	}
 
@@ -1370,7 +1388,7 @@ DispatchResult const & GuiApplication::dispatch(FuncRequest const & cmd)
 	updateCurrentView(cmd, dr);
 
 	// the buffer may have been closed by one action
-	if (theBufferList().isLoaded(buffer))
+	if (theBufferList().isLoaded(buffer) || theBufferList().isInternal(buffer))
 		buffer->undo().endUndoGroup();
 
 	d->dispatch_result_ = dr;
@@ -1845,7 +1863,7 @@ void GuiApplication::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 			dispatch(func);
 		}
 		// the buffer may have been closed by one action
-		if (theBufferList().isLoaded(buffer))
+		if (theBufferList().isLoaded(buffer) || theBufferList().isInternal(buffer))
 			buffer->undo().endUndoGroup();
 		break;
 	}
@@ -2031,9 +2049,8 @@ void GuiApplication::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 			if (current_view_ == 0)
 				createView();
 		}
-		// fall through
 	}
-
+	// fall through
 	default:
 		// The LFUN must be for one of GuiView, BufferView, Buffer or Cursor;
 		// let's try that:
@@ -2676,7 +2693,8 @@ bool GuiApplication::notify(QObject * receiver, QEvent * event)
 #endif
 			// In release mode, try to exit gracefully.
 			this->exit(1);
-
+		// FIXME: GCC 7 thinks we can fall through here. Can we?
+		// fall through
 		case BufferException: {
 			if (!current_view_ || !current_view_->documentBufferView())
 				return false;
