@@ -76,7 +76,7 @@ private:
 	void clearParams();
 	void dispatchParams();
 	bool isBufferDependent() const { return true; }
-	void saveSession() const;
+	void saveSession(QSettings & settings) const;
 	void restoreSession();
 	/** Disconnect from the inset when the Apply button is pressed.
 	 *  Allows easy insertion of multiple citations.
