@@ -75,7 +75,7 @@ char const * const rorigin_gui_strs[] = {
 
 size_t const rorigin_size = sizeof(rorigin_lyx_strs) / sizeof(char *);
 
-static string autostr = N_("automatically");
+static string const autostr = N_("automatically");
 
 } // namespace anon
 
@@ -196,8 +196,6 @@ GuiGraphics::GuiGraphics(GuiView & lv)
 		this, SLOT(change_adaptor()));
 	connect(draftCB, SIGNAL(stateChanged(int)),
 		this, SLOT(change_adaptor()));
-	connect(unzipCB, SIGNAL(stateChanged(int)),
-		this, SLOT(change_adaptor()));
 	// FIXME: we should connect to clicked() when we move to Qt 4.2	because
 	// the toggled(bool) signal is also trigged when we update the widgets
 	// (rgh-4/07) this isn't as much or a problem as it was, because we're now
@@ -223,11 +221,9 @@ GuiGraphics::GuiGraphics(GuiView & lv)
 	bc().addReadOnly(filenameL);
 	bc().addReadOnly(filename);
 	bc().addReadOnly(browsePB);
-	bc().addReadOnly(unzipCB);
 	bc().addReadOnly(bbFrame);
 	bc().addReadOnly(draftCB);
 	bc().addReadOnly(clip);
-	bc().addReadOnly(unzipCB);
 	bc().addReadOnly(displayGB);
 	bc().addReadOnly(sizeGB);
 	bc().addReadOnly(rotationGB);
@@ -529,7 +525,7 @@ void GuiGraphics::paramsToDialog(InsetGraphicsParams const & igp)
 	filename->setText(toqstr(name));
 
 	// set the bounding box values
-	if (igp.bb.empty()) {
+	if (igp.bbox.empty()) {
 		string const bb = readBoundingBox(igp.filename.absFileName());
 		// the values from the file always have the bigpoint-unit bp
 		doubleToWidget(lbX, token(bb, ' ', 0));
@@ -543,46 +539,24 @@ void GuiGraphics::paramsToDialog(InsetGraphicsParams const & igp)
 		bbChanged = false;
 	} else {
 		// get the values from the inset
-		Length anyLength;
-		string const xl = token(igp.bb, ' ', 0);
-		string const yl = token(igp.bb, ' ', 1);
-		string const xr = token(igp.bb, ' ', 2);
-		string const yr = token(igp.bb, ' ', 3);
-		if (isValidLength(xl, &anyLength)) {
-			doubleToWidget(lbX, anyLength.value());
-			string const unit = unit_name[anyLength.unit()];
-			lbXunit->setCurrentIndex(lbXunit->findData(toqstr(unit)));
-		} else {
-			lbX->setText(toqstr(xl));
-		}
-		if (isValidLength(yl, &anyLength)) {
-			doubleToWidget(lbY, anyLength.value());
-			string const unit = unit_name[anyLength.unit()];
-			lbYunit->setCurrentIndex(lbYunit->findData(toqstr(unit)));
-		} else {
-			lbY->setText(toqstr(xl));
-		}
-		if (isValidLength(xr, &anyLength)) {
-			doubleToWidget(rtX, anyLength.value());
-			string const unit = unit_name[anyLength.unit()];
-			rtXunit->setCurrentIndex(rtXunit->findData(toqstr(unit)));
-		} else {
-			rtX->setText(toqstr(xl));
-		}
-		if (isValidLength(yr, &anyLength)) {
-			doubleToWidget(rtY, anyLength.value());
-			string const unit = unit_name[anyLength.unit()];
-			rtYunit->setCurrentIndex(rtYunit->findData(toqstr(unit)));
-		} else {
-			rtY->setText(toqstr(xl));
-		}
+		doubleToWidget(lbX, igp.bbox.xl.value());
+		string unit = unit_name[igp.bbox.xl.unit()];
+		lbXunit->setCurrentIndex(lbXunit->findData(toqstr(unit)));
+		doubleToWidget(lbY, igp.bbox.yb.value());
+		unit = unit_name[igp.bbox.yb.unit()];
+		lbYunit->setCurrentIndex(lbYunit->findData(toqstr(unit)));
+		doubleToWidget(rtX, igp.bbox.xr.value());
+		unit = unit_name[igp.bbox.xr.unit()];
+		rtXunit->setCurrentIndex(rtXunit->findData(toqstr(unit)));
+		doubleToWidget(rtY, igp.bbox.yt.value());
+		unit = unit_name[igp.bbox.yt.unit()];
+		rtYunit->setCurrentIndex(rtYunit->findData(toqstr(unit)));
 		bbChanged = true;
 	}
 
 	// Update the draft and clip mode
 	draftCB->setChecked(igp.draft);
 	clip->setChecked(igp.clip);
-	unzipCB->setChecked(igp.noUnzip);
 	displayGB->setChecked(igp.display);
 	displayscale->setText(toqstr(convert<string>(igp.lyxscale)));
 
@@ -678,9 +652,8 @@ void GuiGraphics::applyView()
 	igp.filename.set(fromqstr(filename->text()), fromqstr(bufferFilePath()));
 
 	// the bb section
-	igp.bb.erase();
+	igp.bbox = graphics::BoundingBox();
 	if (bbChanged) {
-		string bb;
 		string lbXs = widgetToDoubleStr(lbX);
 		string lbYs = widgetToDoubleStr(lbY);
 		string rtXs = widgetToDoubleStr(rtX);
@@ -690,22 +663,17 @@ void GuiGraphics::applyView()
 			convert<int>(rtXs) + convert<int>(rtXs);
 		if (bb_sum) {
 			if (lbXs.empty())
-				bb = "0 ";
-			else
-				bb = lbXs + fromqstr(lbXunit->currentText()) + ' ';
+				lbXs = "0";
+			igp.bbox.xl = Length(lbXs + fromqstr(lbXunit->currentText()));
 			if (lbYs.empty())
-				bb += "0 ";
-			else
-				bb += (lbYs + fromqstr(lbYunit->currentText()) + ' ');
+				lbYs = "0";
+			igp.bbox.yb = Length(lbYs + fromqstr(lbYunit->currentText()));
 			if (rtXs.empty())
-				bb += "0 ";
-			else
-				bb += (rtXs + fromqstr(rtXunit->currentText()) + ' ');
+				rtXs = "0";
+			igp.bbox.xr = Length(rtXs + fromqstr(rtXunit->currentText()));
 			if (rtYs.empty())
-				bb += '0';
-			else
-				bb += (rtYs + fromqstr(rtYunit->currentText()));
-			igp.bb = bb;
+				rtYs = "0";
+			igp.bbox.yt = Length(rtYs + fromqstr(rtYunit->currentText()));
 		}
 	}
 
@@ -732,7 +700,6 @@ void GuiGraphics::applyView()
 		igp.keepAspectRatio = aspectratio->isChecked();
 	}
 
-	igp.noUnzip = unzipCB->isChecked();
 	igp.lyxscale = displayscale->text().toInt();
 	igp.rotateAngle = widgetToDoubleStr(angle);
 
