@@ -18,12 +18,16 @@
 #include "qt_helpers.h"
 #include "Lexer.h"
 
+#include "frontends/Clipboard.h"
+
 #include "support/docstring.h"
 #include "support/FileName.h"
 #include "support/gettext.h"
 
+#include <QDesktopServices>
 #include <QTextBrowser>
 #include <QSyntaxHighlighter>
+#include <QUrl>
 #include <QClipboard>
 
 #include <fstream>
@@ -44,7 +48,7 @@ QRegExp exprInfo("^(Document Class:|LaTeX Font Info:|File:|Package:|Language:|Un
 // Warnings
 QRegExp exprWarning("^(LaTeX Warning|LaTeX Font Warning|Package [\\w\\.]+ Warning|Class \\w+ Warning|Warning--|.*> WARN - ).*$");
 // Errors
-QRegExp exprError("^(!|.*---line [0-9]+ of file|.*> FATAL - |.*> ERROR - ).*$");
+QRegExp exprError("^(!|.*---line [0-9]+ of file|.*> FATAL - |.*> ERROR - |Missing character: There is no ).*$");
 
 
 /////////////////////////////////////////////////////////////////////
@@ -129,11 +133,7 @@ GuiLog::GuiLog(GuiView & lv)
 	highlighter = new LogHighlighter(logTB->document());
 
 	logTB->setReadOnly(true);
-	QFont font(guiApp->typewriterFontName());
-	font.setKerning(false);
-	font.setFixedPitch(true);
-	font.setStyleHint(QFont::TypeWriter);
-	logTB->setFont(font);
+	logTB->setFont(guiApp->typewriterSystemFont());
 }
 
 
@@ -188,6 +188,22 @@ void GuiLog::on_nextWarningPB_clicked()
 }
 
 
+void GuiLog::on_openDirPB_clicked()
+{
+	support::FileName dir = logfile_.onlyPath();
+	if (!dir.exists())
+		return;
+	QUrl qdir(QUrl::fromLocalFile(toqstr(from_utf8(dir.absFileName()))));
+	// Give hints in case of bugs
+	if (!qdir.isValid()) {
+		LYXERR0("QUrl is invalid!");
+		return;
+	}
+	if (!QDesktopServices::openUrl(qdir))
+		LYXERR0("Unable to open QUrl even though dir exists!");
+}
+
+
 void GuiLog::goTo(QRegExp const & exp) const
 {
 	QTextCursor const newc =
@@ -311,12 +327,6 @@ void GuiLog::getContents(ostream & ss) const
 }
 
 
-void GuiLog::on_copyPB_clicked()
-{
-	qApp->clipboard()->setText(logTB->toPlainText());
-}
-
-
 Dialog * createGuiLog(GuiView & lv) { return new GuiLog(lv); }
 
 
