@@ -13,6 +13,8 @@
 
 #include "GuiRef.h"
 
+#include "GuiApplication.h"
+
 #include "Buffer.h"
 #include "BufferList.h"
 #include "FuncRequest.h"
@@ -48,6 +50,26 @@ GuiRef::GuiRef(GuiView & lv)
 
 	at_ref_ = false;
 
+	// The filter bar
+	filter_ = new FancyLineEdit(this);
+#if QT_VERSION >= 0x040600
+	filter_->setButtonPixmap(FancyLineEdit::Right, getPixmap("images/", "editclear", "svgz,png"));
+	filter_->setButtonVisible(FancyLineEdit::Right, true);
+	filter_->setButtonToolTip(FancyLineEdit::Right, qt_("Clear text"));
+	filter_->setAutoHideButton(FancyLineEdit::Right, true);
+#endif
+#if QT_VERSION >= 0x040700
+	filter_->setPlaceholderText(qt_("All available labels"));
+#endif
+	filter_->setToolTip(qt_("Enter string to filter the list of available labels"));
+
+	filterBarL->addWidget(filter_, 0);
+	findKeysLA->setBuddy(filter_);
+
+	sortingCO->addItem(qt_("By Occurrence"), "unsorted");
+	sortingCO->addItem(qt_("Alphabetically (Case-Insensitive)"), "nocase");
+	sortingCO->addItem(qt_("Alphabetically (Case-Sensitive)"), "case");
+
 	refsTW->setColumnCount(1);
 	refsTW->header()->setVisible(false);
 
@@ -59,10 +81,14 @@ GuiRef::GuiRef(GuiView & lv)
 
 	connect(typeCO, SIGNAL(activated(int)),
 		this, SLOT(changed_adaptor()));
+	connect(referenceED, SIGNAL(textChanged(QString)),
+		this, SLOT(refTextChanged(QString)));
 	connect(referenceED, SIGNAL(textChanged(QString)),
 		this, SLOT(changed_adaptor()));
-	connect(findLE, SIGNAL(textEdited(QString)),
+	connect(filter_, SIGNAL(textEdited(QString)),
 		this, SLOT(filterLabels()));
+	connect(filter_, SIGNAL(rightButtonClicked()),
+		this, SLOT(resetFilter()));
 	connect(csFindCB, SIGNAL(clicked()),
 		this, SLOT(filterLabels()));
 	connect(nameED, SIGNAL(textChanged(QString)),
@@ -73,10 +99,8 @@ GuiRef::GuiRef(GuiView & lv)
 		this, SLOT(selectionChanged()));
 	connect(refsTW, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)),
 		this, SLOT(refSelected(QTreeWidgetItem *)));
-	connect(sortCB, SIGNAL(clicked()),
+	connect(sortingCO, SIGNAL(activated(int)),
 		this, SLOT(sortToggled()));
-	connect(caseSensitiveCB, SIGNAL(clicked()),
-		this, SLOT(caseSensitiveToggled()));
 	connect(groupCB, SIGNAL(clicked()),
 		this, SLOT(groupToggled()));
 	connect(gotoPB, SIGNAL(clicked()),
@@ -167,6 +191,14 @@ void GuiRef::refHighlighted(QTreeWidgetItem * sel)
 }
 
 
+void GuiRef::refTextChanged(QString const & str)
+{
+	gotoPB->setEnabled(!str.isEmpty());
+	typeCO->setEnabled(!str.isEmpty());
+	typeLA->setEnabled(!str.isEmpty());
+}
+
+
 void GuiRef::refSelected(QTreeWidgetItem * sel)
 {
 	if (isBufferReadonly())
@@ -190,13 +222,6 @@ void GuiRef::refSelected(QTreeWidgetItem * sel)
 
 
 void GuiRef::sortToggled()
-{
-	caseSensitiveCB->setEnabled(sortCB->isChecked());
-	redoRefs();
-}
-
-
-void GuiRef::caseSensitiveToggled()
 {
 	redoRefs();
 }
@@ -251,7 +276,8 @@ void GuiRef::updateContents()
 	nameL->setHidden(!nameAllowed());
 
 	// restore type settings for new insets
-	if (params_["reference"].empty())
+	bool const new_inset = params_["reference"].empty();
+	if (new_inset)
 		typeCO->setCurrentIndex(orig_type);
 	else
 		typeCO->setCurrentIndex(InsetRef::getType(params_.getCmdName()));
@@ -269,7 +295,7 @@ void GuiRef::updateContents()
 
 	int const thebuffer = theBufferList().bufferNum(buffer().fileName());
 	// restore the buffer combo setting for new insets
-	if (params_["reference"].empty() && restored_buffer_ != -1
+	if (new_inset && restored_buffer_ != -1
 	    && restored_buffer_ < bufferCO->count() && thebuffer == active_buffer_)
 		bufferCO->setCurrentIndex(restored_buffer_);
 	else {
@@ -281,7 +307,9 @@ void GuiRef::updateContents()
 	active_buffer_ = thebuffer;
 
 	updateRefs();
-	bc().setValid(false);
+	// Activate OK/Apply buttons if the users inserts a new ref
+	// and we have a valid pre-setting.
+	bc().setValid(isValid() && new_inset);
 }
 
 
@@ -313,16 +341,14 @@ bool GuiRef::typeAllowed()
 void GuiRef::setGoBack()
 {
 	gotoPB->setText(qt_("&Go Back"));
-	gotoPB->setToolTip("");
-	gotoPB->setToolTip(qt_("Jump back"));
+	gotoPB->setToolTip(qt_("Jump back to the original cursor location"));
 }
 
 
 void GuiRef::setGotoRef()
 {
 	gotoPB->setText(qt_("&Go to Label"));
-	gotoPB->setToolTip("");
-	gotoPB->setToolTip(qt_("Jump to label"));
+	gotoPB->setToolTip(qt_("Jump to the selected label"));
 }
 
 
@@ -389,13 +415,14 @@ void GuiRef::redoRefs()
 	if (noprefix)
 		refsCategories.insert(0, qt_("<No prefix>"));
 
-	if (sortCB->isEnabled() && sortCB->isChecked()) {
-		if(caseSensitiveCB->isEnabled() && caseSensitiveCB->isChecked())
-			qSort(refsStrings.begin(), refsStrings.end());
-		else
-			qSort(refsStrings.begin(), refsStrings.end(),
-			      caseInsensitiveLessThan /*defined above*/);
-	}
+	QString const sort = sortingCO->isEnabled() ?
+				sortingCO->itemData(sortingCO->currentIndex()).toString()
+				: QString();
+	if (sort == "nocase")
+		qSort(refsStrings.begin(), refsStrings.end(),
+		      caseInsensitiveLessThan /*defined above*/);
+	else if (sort == "case")
+		qSort(refsStrings.begin(), refsStrings.end());
 
 	if (groupCB->isChecked()) {
 		QList<QTreeWidgetItem *> refsCats;
@@ -456,6 +483,10 @@ void GuiRef::redoRefs()
 	// Re-activate the emission of signals by these widgets.
 	refsTW->blockSignals(false);
 	referenceED->blockSignals(false);
+
+	gotoPB->setEnabled(!referenceED->text().isEmpty());
+	typeCO->setEnabled(!referenceED->text().isEmpty());
+	typeLA->setEnabled(!referenceED->text().isEmpty());
 }
 
 
@@ -469,13 +500,11 @@ void GuiRef::updateRefs()
 		Buffer const * buf = theBufferList().getBuffer(name);
 		buf->getLabelList(refs_);
 	}
-	sortCB->setEnabled(!refs_.empty());
-	caseSensitiveCB->setEnabled(sortCB->isEnabled() && sortCB->isChecked());
+	sortingCO->setEnabled(!refs_.empty());
 	refsTW->setEnabled(!refs_.empty());
 	groupCB->setEnabled(!refs_.empty());
 	// refsTW should only be the focus proxy when it is enabled
 	setFocusProxy(refs_.empty() ? 0 : refsTW);
-	gotoPB->setEnabled(!refs_.empty());
 	redoRefs();
 }
 
@@ -507,13 +536,20 @@ void GuiRef::filterLabels()
 	while (*it) {
 		(*it)->setHidden(
 			(*it)->childCount() == 0
-			&& !(*it)->text(0).contains(findLE->text(), cs)
+			&& !(*it)->text(0).contains(filter_->text(), cs)
 		);
 		++it;
 	}
 }
 
 
+void GuiRef::resetFilter()
+{
+	filter_->setText(QString());
+	filterLabels();
+}
+
+
 bool GuiRef::initialiseParams(std::string const & data)
 {
 	InsetCommand::string2params(data, params_);
