@@ -784,7 +784,7 @@ void GuiWorkArea::contextMenuEvent(QContextMenuEvent * e)
 	}
 	
 	if (name.empty()) {
-		QAbstractScrollArea::contextMenuEvent(e);
+		e->accept();
 		return;
 	}
 	// always show mnemonics when the keyboard is used to show the context menu
@@ -792,7 +792,7 @@ void GuiWorkArea::contextMenuEvent(QContextMenuEvent * e)
 	bool const keyboard = (e->reason() == QContextMenuEvent::Keyboard);
 	QMenu * menu = guiApp->menus().menu(toqstr(name), *d->lyx_view_, keyboard);
 	if (!menu) {
-		QAbstractScrollArea::contextMenuEvent(e);
+		e->accept();
 		return;
 	}
 	// Position the menu to the right.
@@ -1009,12 +1009,18 @@ void GuiWorkArea::generateSyntheticMouseEvent()
 
 	// In which paragraph do we have to set the cursor ?
 	Cursor & cur = d->buffer_view_->cursor();
-	// FIXME: we don't know howto handle math.
+	// FIXME: we don't know how to handle math.
 	Text * text = cur.text();
 	if (!text)
 		return;
 	TextMetrics const & tm = d->buffer_view_->textMetrics(text);
 
+	// Quit gracefully if there are no metrics, since otherwise next
+	// line would crash (bug #10324).
+	// This situation seems related to a (not yet understood) timing problem.
+	if (tm.empty())
+		return;
+
 	pair<pit_type, const ParagraphMetrics *> pp = up ? tm.first() : tm.last();
 	ParagraphMetrics const & pm = *pp.second;
 	pit_type const pit = pp.first;
