@@ -25,7 +25,7 @@ namespace frontend {
 class LaTeXHighlighter : public QSyntaxHighlighter
 {
 public:
-	LaTeXHighlighter(QTextDocument * parent);
+	explicit LaTeXHighlighter(QTextDocument * parent, bool at_letter = false);
 
 protected:
 	void highlightBlock(QString const & text);
@@ -35,6 +35,8 @@ private:
 	QTextCharFormat keywordFormat;
 	QTextCharFormat mathFormat;
 	QTextCharFormat warningFormat;
+	// is at a letter? (as in the preamble)
+	bool const at_letter_;
 };
 
 } // namespace frontend
