@@ -103,9 +103,14 @@ public:
 //
 /////////////////////////////////////////////////////////////////////
 
-struct LayoutBox::Private
+class LayoutBox::Private
 {
+	/// noncopyable
+	Private(Private const &);
+	void operator=(Private const &);
+public:
 	Private(LayoutBox * parent, GuiView & gv) : p(parent), owner_(gv),
+		inset_(0),
 		// set the layout model with two columns
 		// 1st: translated layout names
 		// 2nd: raw layout names
@@ -522,7 +527,7 @@ bool LayoutBox::eventFilter(QObject * o, QEvent * e)
 	
 void LayoutBox::setIconSize(QSize size)
 {
-#ifdef Q_WS_MACX
+#ifdef Q_OS_MAC
 	bool small = size.height() < 20;
 	setAttribute(Qt::WA_MacSmallSize, small);
 	setAttribute(Qt::WA_MacNormalSize, !small);
