@@ -194,7 +194,7 @@ ToolbarInfo & ToolbarInfo::read(Lexer & lex)
 		case TO_IMPORTFORMATS:
 		case TO_UPDATEFORMATS:
 		case TO_VIEWFORMATS: {
-			vector<Format const *> formats = (code == TO_IMPORTFORMATS) ?
+			FormatList formats = (code == TO_IMPORTFORMATS) ?
 				theConverters().importableFormats() :
 				theConverters().exportableFormats(code != TO_EXPORTFORMATS);
 			sort(formats.begin(), formats.end());
@@ -232,7 +232,7 @@ ToolbarInfo & ToolbarInfo::read(Lexer & lex)
 				FuncRequest func(lfun, (*fit)->name(),
 						FuncRequest::TOOLBAR);
 				add(ToolbarItem(ToolbarItem::COMMAND, func,
-						bformat(tooltip, prettyname)));
+						bformat(tooltip, translateIfPossible(prettyname))));
 			}
 			break;
 		}
