@@ -70,7 +70,7 @@ FileName const unique_tex_filename(FileName const & bufferpath)
 }
 
 
-lyx::Converter const * setConverter(string const from)
+lyx::Converter const * setConverter(string const & from)
 {
 	typedef vector<string> FmtList;
 	typedef lyx::graphics::Cache GCache;
@@ -88,6 +88,7 @@ lyx::Converter const * setConverter(string const from)
 			return ptr;
 	}
 
+	// FIXME THREAD
 	static bool first = true;
 	if (first) {
 		first = false;
@@ -221,7 +222,7 @@ private:
 	/// Called by the ForkedCall process that generated the bitmap files.
 	void finishedGenerating(pid_t, int);
 	///
-	void dumpPreamble(otexstream &) const;
+	void dumpPreamble(otexstream &, OutputParams::FLAVOR) const;
 	///
 	void dumpData(odocstream &, BitmapFile const &) const;
 
@@ -252,6 +253,10 @@ private:
 	///
 	mutable int font_scaling_factor_;
 	///
+	mutable int fg_color_;
+	///
+	mutable int bg_color_;
+	///
 	QTimer * delay_refresh_;
 	///
 	bool finished_generating_;
@@ -405,9 +410,14 @@ namespace graphics {
 PreviewLoader::Impl::Impl(PreviewLoader & p, Buffer const & b)
 	: parent_(p), buffer_(b), finished_generating_(true)
 {
-	font_scaling_factor_ = buffer_.isExporting()
-		? int(75.0 * buffer_.params().html_math_img_scale)
-		: int(0.01 * lyxrc.dpi * lyxrc.zoom * lyxrc.preview_scale_factor);
+	font_scaling_factor_ = int(buffer_.fontScalingFactor());
+	if (theApp()) {
+		fg_color_ = strtol(theApp()->hexName(foregroundColor()).c_str(), 0, 16);
+		bg_color_ = strtol(theApp()->hexName(backgroundColor()).c_str(), 0, 16);
+	} else {
+		fg_color_ = 0x0;
+		bg_color_ = 0xffffff;
+	}
 	if (!pconverter_)
 		pconverter_ = setConverter("lyxpreview");
 
@@ -433,13 +443,19 @@ PreviewLoader::Impl::~Impl()
 PreviewImage const *
 PreviewLoader::Impl::preview(string const & latex_snippet) const
 {
-	int fs = buffer_.isExporting()
-		? int(75.0 * buffer_.params().html_math_img_scale)
-		: int(0.01 * lyxrc.dpi * lyxrc.zoom * lyxrc.preview_scale_factor);
-	if (font_scaling_factor_ != fs) {
-		// Schedule refresh of all previews on zoom changes.
+	int fs = int(buffer_.fontScalingFactor());
+	int fg = 0x0;
+	int bg = 0xffffff;
+	if (theApp()) {
+		fg = strtol(theApp()->hexName(foregroundColor()).c_str(), 0, 16);
+		bg = strtol(theApp()->hexName(backgroundColor()).c_str(), 0, 16);
+	}
+	if (font_scaling_factor_ != fs || fg_color_ != fg || bg_color_ != bg) {
+		// Schedule refresh of all previews on zoom or color changes.
 		// The previews are regenerated only after the zoom factor
 		// has not been changed for about 1 second.
+		fg_color_ = fg;
+		bg_color_ = bg;
 		delay_refresh_->start(1000);
 	}
 	// Don't try to access the cache until we are done.
@@ -452,9 +468,7 @@ PreviewLoader::Impl::preview(string const & latex_snippet) const
 
 void PreviewLoader::Impl::refreshPreviews()
 {
-	font_scaling_factor_ = buffer_.isExporting()
-		? int(75.0 * buffer_.params().html_math_img_scale)
-		: int(0.01 * lyxrc.dpi * lyxrc.zoom * lyxrc.preview_scale_factor);
+	font_scaling_factor_ = int(buffer_.fontScalingFactor());
 	// Reschedule refresh until the previous process completed.
 	if (!finished_generating_) {
 		delay_refresh_->start(1000);
@@ -594,7 +608,7 @@ void PreviewLoader::Impl::startLoading(bool wait)
 
 	// Create an InProgress instance to place in the map of all
 	// such processes if it starts correctly.
-	InProgress inprogress(filename_base, pending_, pconverter_->to);
+	InProgress inprogress(filename_base, pending_, pconverter_->to());
 
 	// clear pending_, so we're ready to start afresh.
 	pending_.clear();
@@ -624,7 +638,55 @@ void PreviewLoader::Impl::startLoading(bool wait)
 		return;
 	}
 	of << "\\batchmode\n";
-	dumpPreamble(os);
+
+	// Set \jobname of previews to the document name (see bug 9627)
+	of << "\\def\\jobname{"
+	   << from_utf8(changeExtension(buffer_.latexName(true), ""))
+	   << "}\n";
+
+	LYXERR(Debug::LATEX, "Format = " << buffer_.params().getDefaultOutputFormat());
+	string latexparam = "";
+	bool docformat = !buffer_.params().default_output_format.empty()
+			&& buffer_.params().default_output_format != "default";
+	// Use LATEX flavor if the document does not specify a specific
+	// output format (see bug 9371).
+	OutputParams::FLAVOR flavor = docformat
+					? buffer_.params().getOutputFlavor()
+					: OutputParams::LATEX;
+	if (buffer_.params().encoding().package() == Encoding::japanese) {
+		latexparam = " --latex=platex";
+		flavor = OutputParams::LATEX;
+	}
+	else if (buffer_.params().useNonTeXFonts) {
+		if (flavor == OutputParams::LUATEX)
+			latexparam = " --latex=lualatex";
+		else {
+			flavor = OutputParams::XETEX;
+			latexparam = " --latex=xelatex";
+		}
+	}
+	else {
+		switch (flavor) {
+			case OutputParams::PDFLATEX:
+				latexparam = " --latex=pdflatex";
+				break;
+			case OutputParams::XETEX:
+				latexparam = " --latex=xelatex";
+				break;
+			case OutputParams::LUATEX:
+				latexparam = " --latex=lualatex";
+				break;
+			case OutputParams::DVILUATEX:
+				latexparam = " --latex=dvilualatex";
+				break;
+			default:
+				flavor = OutputParams::LATEX;
+		}
+	}
+	dumpPreamble(os, flavor);
+	// handle inputenc etc.
+	// I think, this is already hadled by dumpPreamble(): Kornel
+	// buffer_.params().writeEncodingPreamble(os, features);
 	of << "\n\\begin{document}\n";
 	dumpData(of, inprogress.snippets);
 	of << "\n\\end{document}\n";
@@ -634,15 +696,12 @@ void PreviewLoader::Impl::startLoading(bool wait)
 					 << "File was not closed properly.");
 		return;
 	}
-	
+
 	// The conversion command.
 	ostringstream cs;
-	cs << pconverter_->command
+	cs << pconverter_->command()
 	   << " " << quoteName(latexfile.toFilesystemEncoding())
 	   << " --dpi " << font_scaling_factor_;
-	if (lyxerr.debugging(Debug::GRAPHICS)) {
-		cs << " --verbose";
-	}
 
 	// FIXME XHTML 
 	// The colors should be customizable.
@@ -653,11 +712,7 @@ void PreviewLoader::Impl::startLoading(bool wait)
 		   << " --bg " << theApp()->hexName(bg);
 	}
 
-	// FIXME what about LuaTeX?
-	if (buffer_.params().useNonTeXFonts)
-		cs << " --latex=xelatex";
-	if (buffer_.params().encoding().package() == Encoding::japanese)
-		cs << " --latex=platex";
+	cs << latexparam;
 	if (buffer_.params().bibtex_command != "default")
 		cs << " --bibtex=" << quoteName(buffer_.params().bibtex_command);
 	else if (buffer_.params().encoding().package() == Encoding::japanese)
@@ -667,11 +722,12 @@ void PreviewLoader::Impl::startLoading(bool wait)
 	if (buffer_.params().bufferFormat() == "lilypond-book")
 		cs << " --lilypond";
 
-	string const command = libScriptSearch(cs.str());
+	string const command = cs.str();
 
 	if (wait) {
-		ForkedCall call(buffer_.filePath());
+		ForkedCall call(buffer_.filePath(), buffer_.layoutPos());
 		int ret = call.startScript(ForkedProcess::Wait, command);
+		// FIXME THREAD
 		static int fake = (2^20) + 1;
 		int pid = fake++;
 		inprogress.pid = pid;
@@ -702,6 +758,11 @@ void PreviewLoader::Impl::startLoading(bool wait)
 }
 
 
+double PreviewLoader::displayPixelRatio() const
+{
+	return buffer().params().display_pixel_ratio;
+}
+
 void PreviewLoader::Impl::finishedGenerating(pid_t pid, int retval)
 {
 	// Paranoia check!
@@ -767,14 +828,12 @@ void PreviewLoader::Impl::finishedGenerating(pid_t pid, int retval)
 }
 
 
-void PreviewLoader::Impl::dumpPreamble(otexstream & os) const
+void PreviewLoader::Impl::dumpPreamble(otexstream & os, OutputParams::FLAVOR flavor) const
 {
 	// Dump the preamble only.
+	LYXERR(Debug::LATEX, "dumpPreamble, flavor == " << flavor);
 	OutputParams runparams(&buffer_.params().encoding());
-	if (buffer_.params().useNonTeXFonts)
-		runparams.flavor = OutputParams::XETEX;
-	else
-		runparams.flavor = OutputParams::LATEX;
+	runparams.flavor = flavor;
 	runparams.nice = true;
 	runparams.moving_arg = true;
 	runparams.free_spacing = true;
