@@ -6,6 +6,7 @@
  *
  * \author Angus Leeming
  * \author Martin Vermeer
+ * \author Uwe Stöhr
  *
  * Full author contact details are available in file CREDITS.
  */
@@ -52,6 +53,16 @@ public:
 	Length height;
 	///
 	std::string height_special;
+	///
+	Length thickness;
+	///
+	Length separation;
+	///
+	Length shadowsize;
+	///
+	std::string framecolor;
+	///
+	std::string backgroundcolor;
 };
 
 
@@ -104,8 +115,12 @@ public:
 	///
 	ColorCode backgroundColor(PainterInfo const &) const;
 	///
+	LyXAlignment contentAlignment() const;
+	///
 	bool allowParagraphCustomization(idx_type = 0) const { return !forcePlainLayout(); }
 	///
+	bool allowMultiPar() const;
+	///
 	bool forcePlainLayout(idx_type = 0) const;
 	///
 	bool neverIndent() const { return true; }
