@@ -25,6 +25,7 @@
 #include "TextClass.h"
 
 #include "support/gettext.h"
+#include "support/lstrings.h"
 
 #include <ostream>
 
@@ -66,8 +67,25 @@ InsetLayout::InsetDecoration InsetFlex::decoration() const
 
 void InsetFlex::write(ostream & os) const
 {
-	os << "Flex " <<
-		(name_.empty() ? "undefined" : name_) << "\n";
+	os << "Flex ";
+	string name;
+	if (name_.empty())
+		name = "undefined";
+	else {
+		InsetLayout const & il = getLayout();
+		// use il.name(), since this resolves obsoleted InsetLayout names
+		if (il.name() == "undefined")
+			// This is the name of the plain_insetlayout_. We assume that the
+			// name resolution has failed.
+			name = name_;
+		else {
+			name = to_utf8(il.name());
+			// Remove the "Flex:" prefix, if it is present
+			if (support::prefixIs(name, "Flex:"))
+				name = support::split(name, ':');
+		}
+	}
+	os << name << "\n";
 	InsetCollapsable::write(os);
 }
 
