@@ -127,7 +127,7 @@ void InsetFloat::setCaptionType(std::string const & type)
 	params_.type = captionType();
 	// check if the float type exists
 	if (buffer().params().documentClass().floats().typeExist(params_.type))
-		setLabel(_("float: ") + floatName(params_.type));
+		setNewLabel();
 	else
 		setLabel(bformat(_("ERROR: Unknown float type: %1$s"), from_utf8(params_.type)));
 }
@@ -207,6 +207,8 @@ bool InsetFloat::getStatus(Cursor & cur, FuncRequest const & cmd,
 			flag.setEnabled(false);
 			return true;
 		}
+		// no subfloat:
+		// fall through
 
 	default:
 		return InsetCaptionable::getStatus(cur, cmd, flag);
