@@ -14,7 +14,7 @@
 #define INSETGRAPHICSPARAMS_H
 
 
-#include "Length.h"
+#include "graphics/GraphicsParams.h"
 
 #include "support/FileName.h"
 
@@ -48,13 +48,11 @@ public:
 	bool keepAspectRatio;
 	/// draft mode
 	bool draft;
-	/// what to do with zipped files
-	bool noUnzip;
 	/// scale image before rotating
 	bool scaleBeforeRotation;
 
-	/// The bounding box with "xLB yLB yRT yRT ", divided by a space!
-	std::string bb;
+	/// The bounding box
+	graphics::BoundingBox bbox;
 	/// clip image
 	bool clip;
 
@@ -70,12 +68,13 @@ public:
 	///
 	InsetGraphicsParams(InsetGraphicsParams const &);
 	///
-	void operator=(InsetGraphicsParams const &);
+	InsetGraphicsParams & operator=(InsetGraphicsParams const &);
 	/// Save the parameters in the LyX format stream.
 	/// Buffer is needed to figure out if a figure is embedded.
 	void Write(std::ostream & os, Buffer const & buf) const;
 	/// If the token belongs to our parameters, read it.
-	bool Read(Lexer & lex, std::string const & token, std::string const & bufpath);
+	bool Read(Lexer & lex, std::string const & token, Buffer const & buf,
+	          bool allowOrigin);
 	/// convert
 	// Only a subset of InsetGraphicsParams is needed for display purposes.
 	// This function also interrogates lyxrc to ascertain whether
