@@ -31,7 +31,6 @@
 #include "LayoutFile.h"
 #include "LayoutModuleList.h"
 #include "LyX.h"
-#include "LyXRC.h"
 #include "Lexer.h"
 #include "MetricsInfo.h"
 #include "output_plaintext.h"
@@ -128,7 +127,7 @@ bool isVerbatim(InsetCommandParams const & params)
 bool isInputOrInclude(InsetCommandParams const & params)
 {
 	Types const t = type(params);
- 	return t == INPUT || t == INCLUDE;
+	return t == INPUT || t == INCLUDE;
 }
 
 
@@ -689,9 +688,9 @@ void InsetInclude::latex(otexstream & os, OutputParams const & runparams) const
 		// and language.
 		Encoding const * const oldEnc = runparams.encoding;
 		Language const * const oldLang = runparams.master_language;
-		// If the master has full unicode flavor (XeTeX, LuaTeX),
+		// If the master uses non-TeX fonts (XeTeX, LuaTeX),
 		// the children must be encoded in plain utf8!
-		runparams.encoding = runparams.isFullUnicode() ?
+		runparams.encoding = masterBuffer->params().useNonTeXFonts ?
 			encodings.fromLyXName("utf8-plain")
 			: &tmp->params().encoding();
 		runparams.master_language = buffer().params().language;
@@ -992,7 +991,7 @@ void InsetInclude::metrics(MetricsInfo & mi, Dimension & dim) const
 	LBUFERR(mi.base.bv);
 
 	bool use_preview = false;
-	if (RenderPreview::status() != LyXRC::PREVIEW_OFF) {
+	if (RenderPreview::previewText()) {
 		graphics::PreviewImage const * pimage =
 			preview_->getPreviewImage(mi.base.bv->buffer());
 		use_preview = pimage && pimage->image();
@@ -1018,7 +1017,7 @@ void InsetInclude::draw(PainterInfo & pi, int x, int y) const
 	LBUFERR(pi.base.bv);
 
 	bool use_preview = false;
-	if (RenderPreview::status() != LyXRC::PREVIEW_OFF) {
+	if (RenderPreview::previewText()) {
 		graphics::PreviewImage const * pimage =
 			preview_->getPreviewImage(pi.base.bv->buffer());
 		use_preview = pimage && pimage->image();
@@ -1104,8 +1103,7 @@ void add_preview(RenderMonitoredPreview & renderer, InsetInclude const & inset,
 		 Buffer const & buffer)
 {
 	InsetCommandParams const & params = inset.params();
-	if (RenderPreview::status() != LyXRC::PREVIEW_OFF &&
-	    preview_wanted(params, buffer)) {
+	if (RenderPreview::previewText() && preview_wanted(params, buffer)) {
 		renderer.setAbsFile(includedFileName(buffer, params));
 		docstring const snippet = latexString(inset);
 		renderer.addPreview(snippet, buffer);
@@ -1127,41 +1125,42 @@ void InsetInclude::addPreview(DocIterator const & /*inset_pos*/,
 }
 
 
-void InsetInclude::addToToc(DocIterator const & cpit, bool output_active) const
+void InsetInclude::addToToc(DocIterator const & cpit, bool output_active,
+							UpdateType utype) const
 {
 	TocBackend & backend = buffer().tocBackend();
 
 	if (isListings(params())) {
 		if (label_)
-			label_->addToToc(cpit, output_active);
+			label_->addToToc(cpit, output_active, utype);
 
 		InsetListingsParams p(to_utf8(params()["lstparams"]));
 		string caption = p.getParamValue("caption");
 		if (caption.empty())
 			return;
-		Toc & toc = backend.toc("listing");
-		docstring str = convert<docstring>(toc.size() + 1)
+		shared_ptr<Toc> toc = backend.toc("listing");
+		docstring str = convert<docstring>(toc->size() + 1)
 			+ ". " +  from_utf8(caption);
 		DocIterator pit = cpit;
-		toc.push_back(TocItem(pit, 0, str, output_active));
-		return;
+		toc->push_back(TocItem(pit, 0, str, output_active));
+	} else {
+		Buffer const * const childbuffer = getChildBuffer();
+		if (!childbuffer)
+			return;
+
+		shared_ptr<Toc> toc = backend.toc("child");
+		docstring str = childbuffer->fileName().displayName();
+		toc->push_back(TocItem(cpit, 0, str, output_active));
+
+		childbuffer->tocBackend().update(output_active, utype);
+		TocList const & childtoclist = childbuffer->tocBackend().tocs();
+		TocList::const_iterator it = childtoclist.begin();
+		TocList::const_iterator const end = childtoclist.end();
+		for(; it != end; ++it) {
+			shared_ptr<Toc> toc = backend.toc(it->first);
+			toc->insert(toc->end(), it->second->begin(), it->second->end());
+		}
 	}
-	Buffer const * const childbuffer = getChildBuffer();
-	if (!childbuffer)
-		return;
-
-	Toc & toc = backend.toc("child");
-	docstring str = childbuffer->fileName().displayName();
-	toc.push_back(TocItem(cpit, 0, str, output_active));
-
-	TocList & toclist = backend.tocs();
-	childbuffer->tocBackend().update(output_active);
-	TocList const & childtoclist = childbuffer->tocBackend().tocs();
-	TocList::const_iterator it = childtoclist.begin();
-	TocList::const_iterator const end = childtoclist.end();
-	for(; it != end; ++it)
-		toclist[it->first].insert(toclist[it->first].end(),
-			it->second.begin(), it->second.end());
 }
 
 
