@@ -200,13 +200,13 @@ void InsetIndex::doDispatch(Cursor & cur, FuncRequest & cmd)
 
 	case LFUN_INSET_MODIFY: {
 		if (cmd.getArg(0) == "changetype") {
-			cur.recordUndoInset(ATOMIC_UNDO, this);
+			cur.recordUndoInset(this);
 			params_.index = from_utf8(cmd.getArg(1));
 			break;
 		}
 		InsetIndexParams params;
 		InsetIndex::string2params(to_utf8(cmd.argument()), params);
-		cur.recordUndoInset(ATOMIC_UNDO, this);
+		cur.recordUndoInset(this);
 		params_.index = params.index;
 		// what we really want here is a TOC update, but that means
 		// a full buffer update
@@ -348,7 +348,8 @@ void InsetIndex::string2params(string const & in, InsetIndexParams & params)
 }
 
 
-void InsetIndex::addToToc(DocIterator const & cpit, bool output_active) const
+void InsetIndex::addToToc(DocIterator const & cpit, bool output_active,
+						  UpdateType utype) const
 {
 	DocIterator pit = cpit;
 	pit.push_back(CursorSlice(const_cast<InsetIndex &>(*this)));
@@ -356,10 +357,11 @@ void InsetIndex::addToToc(DocIterator const & cpit, bool output_active) const
 	string type = "index";
 	if (buffer().masterBuffer()->params().use_indices)
 		type += ":" + to_utf8(params_.index);
-	text().forToc(str, 0);
-	buffer().tocBackend().toc(type).push_back(TocItem(pit, 0, str, output_active));
+	// this is unlikely to be terribly long
+	text().forOutliner(str, INT_MAX);
+	buffer().tocBackend().toc(type)->push_back(TocItem(pit, 0, str, output_active));
 	// Proceed with the rest of the inset.
-	InsetCollapsable::addToToc(cpit, output_active);
+	InsetCollapsable::addToToc(cpit, output_active, utype);
 }
 
 
@@ -430,7 +432,7 @@ ParamInfo const & InsetPrintIndex::findInfo(string const & /* cmdName */)
 	static ParamInfo param_info_;
 	if (param_info_.empty()) {
 		param_info_.add("type", ParamInfo::LATEX_OPTIONAL,
-                        ParamInfo::HANDLING_ESCAPE);
+		                ParamInfo::HANDLING_ESCAPE);
 		param_info_.add("name", ParamInfo::LATEX_REQUIRED);
 	}
 	return param_info_;
@@ -688,13 +690,13 @@ docstring InsetPrintIndex::xhtml(XHTMLStream &, OutputParams const & op) const
 	if (bp.use_indices && getParam("type") != from_ascii("idx"))
 		return docstring();
 	
-	Toc const & toc = buffer().tocBackend().toc("index");
-	if (toc.empty())
+	shared_ptr<Toc const> toc = buffer().tocBackend().toc("index");
+	if (toc->empty())
 		return docstring();
 
 	// Collect the index entries in a form we can use them.
-	Toc::const_iterator it = toc.begin();
-	Toc::const_iterator const en = toc.end();
+	Toc::const_iterator it = toc->begin();
+	Toc::const_iterator const en = toc->end();
 	vector<IndexEntry> entries;
 	for (; it != en; ++it)
 		if (it->isOutput())
