@@ -28,7 +28,7 @@ public:
 		///
 		std::string short_gui_name;
 	};
-	static type_info types[];
+	static const type_info types[];
 	///
 	static int getType(std::string const & name);
 	///
@@ -64,13 +64,14 @@ public:
 	/// 
 	void toString(odocstream &) const;
 	///
-	void forToc(docstring &, size_t) const;
+	void forOutliner(docstring &, size_t const, bool const) const;
 	///
 	void validate(LaTeXFeatures & features) const;
 	///
 	void updateBuffer(ParIterator const & it, UpdateType);
 	///
-	void addToToc(DocIterator const & di, bool output_active) const;
+	void addToToc(DocIterator const & di, bool output_active,
+				  UpdateType utype) const;
 	///
 	bool forceLTR() const { return true; }
 	//@}
