@@ -881,6 +881,8 @@ public:
 	bool inheritFont() const { return false; }
 	///
 	bool allowsCaptionVariation(std::string const &) const;
+	//
+	bool isTable() const { return true; }
 	///
 	DisplayType display() const;
 	///
@@ -1003,6 +1005,13 @@ private:
 	///
 	Inset * clone() const { return new InsetTabular(*this); }
 
+	///
+	bool hitSelectRow(BufferView const & bv, int x) const;
+	///
+	bool hitSelectColumn(BufferView const & bv, int y) const;
+	/// Returns true if coordinates are on row/column selection zones
+	bool clickable(BufferView const &, int x, int y) const;
+
 	///
 	void drawCellLines(PainterInfo &, int x, int y, row_type row,
 			   idx_type cell) const;
