@@ -53,7 +53,9 @@ void InsetMath::dump() const
 {
 	lyxerr << "---------------------------------------------" << endl;
 	odocstringstream os;
-	WriteStream wi(os, false, true, WriteStream::wsDefault);
+	TexRow texrow(false);
+	otexrowstream ots(os,texrow);
+	WriteStream wi(ots, false, true, WriteStream::wsDefault);
 	write(wi);
 	lyxerr << to_utf8(os.str());
 	lyxerr << "\n---------------------------------------------" << endl;
@@ -156,7 +158,9 @@ HullType InsetMath::getType() const
 ostream & operator<<(ostream & os, MathAtom const & at)
 {
 	odocstringstream oss;
-	WriteStream wi(oss, false, false, WriteStream::wsDefault);
+	TexRow texrow(false);
+	otexrowstream ots(oss,texrow);
+	WriteStream wi(ots, false, false, WriteStream::wsDefault);
 	at->write(wi);
 	return os << to_utf8(oss.str());
 }
@@ -164,7 +168,9 @@ ostream & operator<<(ostream & os, MathAtom const & at)
 
 odocstream & operator<<(odocstream & os, MathAtom const & at)
 {
-	WriteStream wi(os, false, false, WriteStream::wsDefault);
+	TexRow texrow(false);
+	otexrowstream ots(os,texrow);
+	WriteStream wi(ots, false, false, WriteStream::wsDefault);
 	at->write(wi);
 	return os;
 }
