@@ -512,11 +512,10 @@ void InsetMathFrac::validate(LaTeXFeatures & features) const
 		features.require("amsmath");
 	if (features.runparams().math_flavor == OutputParams::MathAsHTML)
 		// CSS adapted from eLyXer
-		features.addPreambleSnippet("<style type=\"text/css\">\n"
+		features.addCSSSnippet(
 			"span.frac{display: inline-block; vertical-align: middle; text-align:center;}\n"
 			"span.numer{display: block;}\n"
-			"span.denom{display: block; border-top: thin solid #000040;}\n"
-			"</style>");
+			"span.denom{display: block; border-top: thin solid #000040;}");
 	InsetMathNest::validate(features);
 }
 
@@ -554,8 +553,8 @@ void InsetMathBinom::metrics(MetricsInfo & mi, Dimension & dim) const
 {
 	Dimension dim0, dim1;
 
-	// FIXME: for an unknown reason the cells must be set directly
-	// after the StyleChanger and cannot be set after the if case
+	// The cells must be set while the RAII objects (StyleChanger,
+	// FracChanger) do still exist and cannot be set after the if case.
 	if (kind_ == DBINOM) {
 		StyleChanger dummy(mi.base, LM_ST_DISPLAY);
 		cell(0).metrics(mi, dim0);
@@ -588,8 +587,8 @@ void InsetMathBinom::draw(PainterInfo & pi, int x, int y) const
 		kind_ == BRACK ? from_ascii("]") : from_ascii(")");
 
 	int m = x + dim.width() / 2;
-	// FIXME: for an unknown reason the cells must be drawn directly
-	// after the StyleChanger and cannot be drawn after the if case
+	// The cells must be drawn while the RAII objects (StyleChanger,
+	// FracChanger) do still exist and cannot be drawn after the if case.
 	if (kind_ == DBINOM) {
 		StyleChanger dummy(pi.base, LM_ST_DISPLAY);
 		cell(0).draw(pi, m - dim0.wid / 2, y - dim0.des - 3 - 5);
@@ -717,11 +716,10 @@ void InsetMathBinom::validate(LaTeXFeatures & features) const
 		if (kind_ == DBINOM || kind_ == TBINOM)
 			features.require("amsmath");
 	} else if (features.runparams().math_flavor == OutputParams::MathAsHTML)
-		features.addPreambleSnippet("<style type=\"text/css\">\n"
+		features.addCSSSnippet(
 			"span.binom{display: inline-block; vertical-align: bottom; text-align:center;}\n"
 			"span.binom span{display: block;}\n"
-			"span.binomdelim{font-size: 2em;}\n"
-			"</style>");
+			"span.binomdelim{font-size: 2em;}");
 	InsetMathNest::validate(features);
 }
 
