@@ -15,7 +15,6 @@
 #include "InsetMathChar.h"
 #include "InsetMathColor.h"
 #include "InsetMathFrac.h"
-#include "InsetMathGrid.h"
 #include "InsetMathNest.h"
 #include "InsetMathScript.h"
 #include "MathExtern.h"
@@ -118,6 +117,37 @@ namespace {
 	}
 
 
+	// writes a preamble for underlined or struck out math display
+	void writeMathdisplayPreamble(WriteStream & os)
+	{
+		if (os.strikeoutMath()) {
+			if (os.ulemCmd() == WriteStream::UNDERLINE)
+				os << "\\raisebox{-\\belowdisplayshortskip}{"
+				      "\\lyxmathsout{\\parbox[b]{\\columnwidth}{";
+			else
+				os << "\\lyxmathsout{\\parbox{\\columnwidth}{";
+		} else if (os.ulemCmd() == WriteStream::UNDERLINE)
+			os << "\\raisebox{-\\belowdisplayshortskip}{"
+			      "\\parbox[b]{\\columnwidth}{";
+		else if (os.ulemCmd() == WriteStream::STRIKEOUT)
+			os << "\\parbox{\\columnwidth}{";
+	}
+
+
+	// writes a postamble for underlined or struck out math display
+	void writeMathdisplayPostamble(WriteStream & os)
+	{
+		if (os.strikeoutMath()) {
+			if (os.ulemCmd() == WriteStream::UNDERLINE)
+				os << "}";
+			os << "}}\\\\\n";
+		} else if (os.ulemCmd() == WriteStream::UNDERLINE)
+			os << "}}\\\\\n";
+		else if (os.ulemCmd() == WriteStream::STRIKEOUT)
+			os << "}\\\\\n";
+	}
+
+
 } // end anon namespace
 
 
@@ -892,6 +922,29 @@ bool InsetMathHull::ams() const
 }
 
 
+bool InsetMathHull::outerDisplay() const
+{
+	switch (type_) {
+	case hullEquation:
+	case hullEqnArray:
+	case hullAlign:
+	case hullFlAlign:
+	case hullGather:
+	case hullMultline:
+		return true;
+	case hullNone:
+	case hullSimple:
+	case hullAlignAt:
+	case hullXAlignAt:
+	case hullXXAlignAt:
+	case hullUnknown:
+	case hullRegexp:
+		break;
+	}
+	return false;
+}
+
+
 Inset::DisplayType InsetMathHull::display() const
 {
 	switch (type_) {
@@ -957,6 +1010,9 @@ void InsetMathHull::validate(LaTeXFeatures & features) const
 				+ bgcol + string("}{\\ensuremath{\\mathtt{#1}}}}"));
 			features.addPreambleSnippet(
 				string("\\newcommand{\\endregexp}{}"));
+		} else if (outerDisplay() && features.inDeletedInset()
+			   && !features.mustProvide("ct-dvipost")) {
+				features.require("ct-tikz-math-sout");
 		}
 
 		// Validation is necessary only if not using AMS math.
@@ -988,6 +1044,8 @@ void InsetMathHull::header_write(WriteStream & os) const
 		break;
 
 	case hullSimple:
+		if (os.ulemCmd())
+			os << "\\mbox{";
 		os << '$';
 		os.startOuterRow();
 		if (cell(0).empty())
@@ -995,6 +1053,7 @@ void InsetMathHull::header_write(WriteStream & os) const
 		break;
 
 	case hullEquation:
+		writeMathdisplayPreamble(os);
 		os << "\n";
 		os.startOuterRow();
 		if (n)
@@ -1008,6 +1067,7 @@ void InsetMathHull::header_write(WriteStream & os) const
 	case hullFlAlign:
 	case hullGather:
 	case hullMultline:
+		writeMathdisplayPreamble(os);
 		os << "\n";
 		os.startOuterRow();
 		os << "\\begin{" << hullName(type_) << star(n) << "}\n";
@@ -1052,6 +1112,8 @@ void InsetMathHull::footer_write(WriteStream & os) const
 
 	case hullSimple:
 		os << '$';
+		if (os.ulemCmd())
+			os << "}";
 		break;
 
 	case hullEquation:
@@ -1061,15 +1123,22 @@ void InsetMathHull::footer_write(WriteStream & os) const
 			os << "\\end{equation" << star(n) << "}\n";
 		else
 			os << "\\]\n";
+		writeMathdisplayPostamble(os);
 		break;
 
 	case hullEqnArray:
 	case hullAlign:
 	case hullFlAlign:
-	case hullAlignAt:
-	case hullXAlignAt:
 	case hullGather:
 	case hullMultline:
+		os << "\n";
+		os.startOuterRow();
+		os << "\\end{" << hullName(type_) << star(n) << "}\n";
+		writeMathdisplayPostamble(os);
+		break;
+
+	case hullAlignAt:
+	case hullXAlignAt:
 		os << "\n";
 		os.startOuterRow();
 		os << "\\end{" << hullName(type_) << star(n) << "}\n";
